@@ -127,7 +127,7 @@ elif sys.platform.startswith("sunos"):
     from ._pssunos import (CONN_IDLE,  # NOQA
                            CONN_BOUND)
 
-else:
+else:  # pragma: no cover
     raise NotImplementedError('platform %s is not supported' % sys.platform)
 
 
@@ -158,7 +158,7 @@ __all__ = [
 ]
 __all__.extend(_psplatform.__extra__all__)
 __author__ = "Giampaolo Rodola'"
-__version__ = "3.0.0"
+__version__ = "3.2.0"
 version_info = tuple([int(num) for num in __version__.split('.')])
 AF_LINK = _psplatform.AF_LINK
 _TOTAL_PHYMEM = None
@@ -193,8 +193,12 @@ class Error(Exception):
     def __init__(self, msg=""):
         self.msg = msg
 
-    def __str__(self):
-        return self.msg
+    def __repr__(self):
+        ret = "%s.%s %s" % (self.__class__.__module__,
+                            self.__class__.__name__, self.msg)
+        return ret.strip()
+
+    __str__ = __repr__
 
 
 class NoSuchProcess(Error):
@@ -482,8 +486,8 @@ class Process(object):
         try:
             # Checking if PID is alive is not enough as the PID might
             # have been reused by another process: we also want to
-            # check process identity.
-            # Process identity / uniqueness over time is greanted by
+            # verify process identity.
+            # Process identity / uniqueness over time is guaranteed by
             # (PID + creation time) and that is verified in __eq__.
             return self == Process(self.pid)
         except NoSuchProcess:
@@ -681,7 +685,7 @@ class Process(object):
             """
             if ioclass is None:
                 if value is not None:
-                    raise ValueError("'ioclass' must be specified")
+                    raise ValueError("'ioclass' argument must be specified")
                 return self._proc.ionice_get()
             else:
                 return self._proc.ionice_set(ioclass, value)
@@ -1007,17 +1011,19 @@ class Process(object):
 
     if _POSIX:
         def _send_signal(self, sig):
-            # XXX: according to "man 2 kill" PID 0 has a special
-            # meaning as it refers to <<every process in the process
-            # group of the calling process>>, so should we prevent
-            # it here?
+            if self.pid == 0:
+                # see "man 2 kill"
+                raise ValueError(
+                    "preventing sending signal to process with PID 0 as it "
+                    "would affect every process in the process group of the "
+                    "calling process (os.getpid()) instead of PID 0")
             try:
                 os.kill(self.pid, sig)
             except OSError as err:
                 if err.errno == errno.ESRCH:
                     self._gone = True
                     raise NoSuchProcess(self.pid, self._name)
-                if err.errno == errno.EPERM:
+                if err.errno in (errno.EPERM, errno.EACCES):
                     raise AccessDenied(self.pid, self._name)
                 raise
 
@@ -1033,8 +1039,14 @@ class Process(object):
         else:
             if sig == signal.SIGTERM:
                 self._proc.kill()
+            # py >= 2.7
+            elif sig in (getattr(signal, "CTRL_C_EVENT", object()),
+                         getattr(signal, "CTRL_BREAK_EVENT", object())):
+                self._proc.send_signal(sig)
             else:
-                raise ValueError("only SIGTERM is supported on Windows")
+                raise ValueError(
+                    "only SIGTERM, CTRL_C_EVENT and CTRL_BREAK_EVENT signals "
+                    "are supported on Windows")
 
     @_assert_pid_not_reused
     def suspend(self):
@@ -1242,7 +1254,10 @@ def process_iter():
             # Process creation time can't be determined hence there's
             # no way to tell whether the pid of the cached process
             # has been reused. Just return the cached version.
-            yield proc
+            if proc is None and pid in _pmap:
+                yield _pmap[pid]
+            else:
+                raise
 
 
 def wait_procs(procs, timeout=None, callback=None):
@@ -1499,23 +1514,20 @@ def cpu_times_percent(interval=None, percpu=False):
             except ZeroDivisionError:
                 field_perc = 0.0
             field_perc = round(field_perc, 1)
-            if _WINDOWS:
-                # XXX
-                # Work around:
-                # https://github.com/giampaolo/psutil/issues/392
-                # CPU times are always supposed to increase over time
-                # or at least remain the same and that's because time
-                # cannot go backwards.
-                # Surprisingly sometimes this might not be the case on
-                # Windows where 'system' CPU time can be smaller
-                # compared to the previous call, resulting in corrupted
-                # percentages (< 0 or > 100).
-                # I really don't know what to do about that except
-                # forcing the value to 0 or 100.
-                if field_perc > 100.0:
-                    field_perc = 100.0
-                elif field_perc < 0.0:
-                    field_perc = 0.0
+            # CPU times are always supposed to increase over time
+            # or at least remain the same and that's because time
+            # cannot go backwards.
+            # Surprisingly sometimes this might not be the case (at
+            # least on Windows and Linux), see:
+            # https://github.com/giampaolo/psutil/issues/392
+            # https://github.com/giampaolo/psutil/issues/645
+            # I really don't know what to do about that except
+            # forcing the value to 0 or 100.
+            if field_perc > 100.0:
+                field_perc = 100.0
+            # `<=` because `-0.0 == 0.0` evaluates to True
+            elif field_perc <= 0.0:
+                field_perc = 0.0
             nums.append(field_perc)
         return _psplatform.scputimes(*nums)
 
@@ -1743,17 +1755,22 @@ def net_if_addrs():
     """Return the addresses associated to each NIC (network interface
     card) installed on the system as a dictionary whose keys are the
     NIC names and value is a list of namedtuples for each address
-    assigned to the NIC. Each namedtuple includes 4 fields:
+    assigned to the NIC. Each namedtuple includes 5 fields:
 
      - family
      - address
      - netmask
      - broadcast
+     - ptp
 
     'family' can be either socket.AF_INET, socket.AF_INET6 or
     psutil.AF_LINK, which refers to a MAC address.
-    'address' is the primary address, 'netmask' and 'broadcast'
-    may be None.
+    'address' is the primary address and it is always set.
+    'netmask' and 'broadcast' and 'ptp' may be None.
+    'ptp' stands for "point to point" and references the destination
+    address on a point to point interface (tipically a VPN).
+    'broadcast' and 'ptp' are mutually exclusive.
+
     Note: you can have more than one address of the same family
     associated with each interface.
     """
@@ -1763,7 +1780,7 @@ def net_if_addrs():
     rawlist = _psplatform.net_if_addrs()
     rawlist.sort(key=lambda x: x[1])  # sort by family
     ret = collections.defaultdict(list)
-    for name, fam, addr, mask, broadcast in rawlist:
+    for name, fam, addr, mask, broadcast, ptp in rawlist:
         if has_enums:
             try:
                 fam = socket.AddressFamily(fam)
@@ -1776,7 +1793,7 @@ def net_if_addrs():
                     # We re-set the family here so that repr(family)
                     # will show AF_LINK rather than AF_PACKET
                     fam = _psplatform.AF_LINK
-        ret[name].append(_common.snic(fam, addr, mask, broadcast))
+        ret[name].append(_common.snic(fam, addr, mask, broadcast, ptp))
     return dict(ret)
 
 
@@ -1820,7 +1837,7 @@ def users():
     return _psplatform.users()
 
 
-def test():
+def test():  # pragma: no cover
     """List info of all currently running processes emulating ps aux
     output.
     """
@@ -1853,14 +1870,6 @@ def test():
                                     time.localtime(sum(pinfo['cpu_times'])))
             try:
                 user = p.username()
-            except KeyError:
-                if _POSIX:
-                    if pinfo['uids']:
-                        user = str(pinfo['uids'].real)
-                    else:
-                        user = ''
-                else:
-                    raise
             except Error:
                 user = ''
             if _WINDOWS and '\\' in user:
