@@ -19,6 +19,20 @@
 #include <linux/version.h>
 #include <sys/syscall.h>
 #include <sys/sysinfo.h>
+#include <sys/ioctl.h>
+#include <sys/socket.h>
+#include <linux/sockios.h>
+#include <linux/if.h>
+
+// see: https://github.com/giampaolo/psutil/issues/659
+#ifdef PSUTIL_ETHTOOL_MISSING_TYPES
+    #include <linux/types.h>
+    typedef __u64 u64;
+    typedef __u32 u32;
+    typedef __u16 u16;
+    typedef __u8 u8;
+#endif
+#include <linux/ethtool.h>
 
 #include "_psutil_linux.h"
 
@@ -46,15 +60,19 @@ enum {
     IOPRIO_WHO_PROCESS = 1,
 };
 
+// May happen on old RedHat versions, see:
+// https://github.com/giampaolo/psutil/issues/607
+#ifndef DUPLEX_UNKNOWN
+    #define DUPLEX_UNKNOWN 0xff
+#endif
+
 static inline int
-ioprio_get(int which, int who)
-{
+ioprio_get(int which, int who) {
     return syscall(__NR_ioprio_get, which, who);
 }
 
 static inline int
-ioprio_set(int which, int who, int ioprio)
-{
+ioprio_set(int which, int who, int ioprio) {
     return syscall(__NR_ioprio_set, which, who, ioprio);
 }
 
@@ -70,17 +88,14 @@ ioprio_set(int which, int who, int ioprio)
  * Return a (ioclass, iodata) Python tuple representing process I/O priority.
  */
 static PyObject *
-psutil_proc_ioprio_get(PyObject *self, PyObject *args)
-{
+psutil_proc_ioprio_get(PyObject *self, PyObject *args) {
     long pid;
     int ioprio, ioclass, iodata;
-    if (! PyArg_ParseTuple(args, "l", &pid)) {
+    if (! PyArg_ParseTuple(args, "l", &pid))
         return NULL;
-    }
     ioprio = ioprio_get(IOPRIO_WHO_PROCESS, pid);
-    if (ioprio == -1) {
+    if (ioprio == -1)
         return PyErr_SetFromErrno(PyExc_OSError);
-    }
     ioclass = IOPRIO_PRIO_CLASS(ioprio);
     iodata = IOPRIO_PRIO_DATA(ioprio);
     return Py_BuildValue("ii", ioclass, iodata);
@@ -93,20 +108,17 @@ psutil_proc_ioprio_get(PyObject *self, PyObject *args)
  * or 0. iodata goes from 0 to 7 depending on ioclass specified.
  */
 static PyObject *
-psutil_proc_ioprio_set(PyObject *self, PyObject *args)
-{
+psutil_proc_ioprio_set(PyObject *self, PyObject *args) {
     long pid;
     int ioprio, ioclass, iodata;
     int retval;
 
-    if (! PyArg_ParseTuple(args, "lii", &pid, &ioclass, &iodata)) {
+    if (! PyArg_ParseTuple(args, "lii", &pid, &ioclass, &iodata))
         return NULL;
-    }
     ioprio = IOPRIO_PRIO_VALUE(ioclass, iodata);
     retval = ioprio_set(IOPRIO_WHO_PROCESS, pid, ioprio);
-    if (retval == -1) {
+    if (retval == -1)
         return PyErr_SetFromErrno(PyExc_OSError);
-    }
     Py_RETURN_NONE;
 }
 #endif
@@ -119,8 +131,7 @@ psutil_proc_ioprio_set(PyObject *self, PyObject *args)
  * 'soft' and 'hard' args must be provided.
  */
 static PyObject *
-psutil_linux_prlimit(PyObject *self, PyObject *args)
-{
+psutil_linux_prlimit(PyObject *self, PyObject *args) {
     long pid;
     int ret, resource;
     struct rlimit old, new;
@@ -128,9 +139,8 @@ psutil_linux_prlimit(PyObject *self, PyObject *args)
     PyObject *soft = NULL;
     PyObject *hard = NULL;
 
-    if (! PyArg_ParseTuple(args, "li|OO", &pid, &resource, &soft, &hard)) {
+    if (! PyArg_ParseTuple(args, "li|OO", &pid, &resource, &soft, &hard))
         return NULL;
-    }
 
     // get
     if (soft == NULL && hard == NULL) {
@@ -179,8 +189,7 @@ psutil_linux_prlimit(PyObject *self, PyObject *args)
  * mount point and filesystem type
  */
 static PyObject *
-psutil_disk_partitions(PyObject *self, PyObject *args)
-{
+psutil_disk_partitions(PyObject *self, PyObject *args) {
     FILE *file = NULL;
     struct mntent *entry;
     PyObject *py_retlist = PyList_New(0);
@@ -230,13 +239,11 @@ error:
  * A wrapper around sysinfo(), return system memory usage statistics.
  */
 static PyObject *
-psutil_linux_sysinfo(PyObject *self, PyObject *args)
-{
+psutil_linux_sysinfo(PyObject *self, PyObject *args) {
     struct sysinfo info;
-    if (sysinfo(&info) != 0) {
-        return PyErr_SetFromErrno(PyExc_OSError);
-    }
 
+    if (sysinfo(&info) != 0)
+        return PyErr_SetFromErrno(PyExc_OSError);
     // note: boot time might also be determined from here
     return Py_BuildValue(
         "(KKKKKK)",
@@ -258,18 +265,15 @@ psutil_linux_sysinfo(PyObject *self, PyObject *args)
 #ifdef CPU_ALLOC
 
 static PyObject *
-psutil_proc_cpu_affinity_get(PyObject *self, PyObject *args)
-{
+psutil_proc_cpu_affinity_get(PyObject *self, PyObject *args) {
     int cpu, ncpus, count, cpucount_s;
     long pid;
     size_t setsize;
     cpu_set_t *mask = NULL;
     PyObject *res = NULL;
 
-    if (!PyArg_ParseTuple(args, "i", &pid)) {
+    if (!PyArg_ParseTuple(args, "i", &pid))
         return NULL;
-    }
-
     ncpus = NCPUS_START;
     while (1) {
         setsize = CPU_ALLOC_SIZE(ncpus);
@@ -301,7 +305,6 @@ psutil_proc_cpu_affinity_get(PyObject *self, PyObject *args)
 #else
             PyObject *cpu_num = PyInt_FromLong(cpu);
 #endif
-            --count;
             if (cpu_num == NULL)
                 goto error;
             if (PyList_Append(res, cpu_num)) {
@@ -309,6 +312,7 @@ psutil_proc_cpu_affinity_get(PyObject *self, PyObject *args)
                 goto error;
             }
             Py_DECREF(cpu_num);
+            --count;
         }
     }
     CPU_FREE(mask);
@@ -327,25 +331,23 @@ error:
  * Alternative implementation in case CPU_ALLOC is not defined.
  */
 static PyObject *
-psutil_proc_cpu_affinity_get(PyObject *self, PyObject *args)
-{
+psutil_proc_cpu_affinity_get(PyObject *self, PyObject *args) {
     cpu_set_t cpuset;
     unsigned int len = sizeof(cpu_set_t);
     long pid;
     int i;
-    PyObject* py_retlist;
-    PyObject *py_cpu_num;
+    PyObject* py_retlist = NULL;
+    PyObject *py_cpu_num = NULL;
 
-    if (!PyArg_ParseTuple(args, "i", &pid)) {
+    if (!PyArg_ParseTuple(args, "i", &pid))
         return NULL;
-    }
-
 	CPU_ZERO(&cpuset);
-    if (sched_getaffinity(pid, len, &cpuset) < 0) {
+    if (sched_getaffinity(pid, len, &cpuset) < 0)
         return PyErr_SetFromErrno(PyExc_OSError);
-    }
 
     py_retlist = PyList_New(0);
+    if (py_retlist == NULL)
+        goto error;
     for (i = 0; i < CPU_SETSIZE; ++i) {
         if (CPU_ISSET(i, &cpuset)) {
             py_cpu_num = Py_BuildValue("i", i);
@@ -353,6 +355,7 @@ psutil_proc_cpu_affinity_get(PyObject *self, PyObject *args)
                 goto error;
             if (PyList_Append(py_retlist, py_cpu_num))
                 goto error;
+            Py_DECREF(py_cpu_num);
         }
     }
 
@@ -369,8 +372,7 @@ error:
  * Set process CPU affinity; expects a bitmask
  */
 static PyObject *
-psutil_proc_cpu_affinity_set(PyObject *self, PyObject *args)
-{
+psutil_proc_cpu_affinity_set(PyObject *self, PyObject *args) {
     cpu_set_t cpu_set;
     size_t len;
     long pid;
@@ -378,9 +380,8 @@ psutil_proc_cpu_affinity_set(PyObject *self, PyObject *args)
     PyObject *py_cpu_set;
     PyObject *py_cpu_seq = NULL;
 
-    if (!PyArg_ParseTuple(args, "lO", &pid, &py_cpu_set)) {
-        goto error;
-    }
+    if (!PyArg_ParseTuple(args, "lO", &pid, &py_cpu_set))
+        return NULL;
 
     if (!PySequence_Check(py_cpu_set)) {
         PyErr_Format(PyExc_TypeError, "sequence argument expected, got %s",
@@ -389,9 +390,8 @@ psutil_proc_cpu_affinity_set(PyObject *self, PyObject *args)
     }
 
     py_cpu_seq = PySequence_Fast(py_cpu_set, "expected a sequence or integer");
-    if (!py_cpu_seq) {
+    if (!py_cpu_seq)
         goto error;
-    }
     seq_len = PySequence_Fast_GET_SIZE(py_cpu_seq);
     CPU_ZERO(&cpu_set);
     for (i = 0; i < seq_len; i++) {
@@ -401,9 +401,8 @@ psutil_proc_cpu_affinity_set(PyObject *self, PyObject *args)
 #else
         long value = PyInt_AsLong(item);
 #endif
-        if (value == -1 && PyErr_Occurred()) {
+        if (value == -1 && PyErr_Occurred())
             goto error;
-        }
         CPU_SET(value, &cpu_set);
     }
 
@@ -417,10 +416,8 @@ psutil_proc_cpu_affinity_set(PyObject *self, PyObject *args)
     Py_RETURN_NONE;
 
 error:
-    if (py_cpu_seq != NULL) {
+    if (py_cpu_seq != NULL)
         Py_DECREF(py_cpu_seq);
-	}
-
     return NULL;
 }
 
@@ -429,8 +426,7 @@ error:
  * Return currently connected users as a list of tuples.
  */
 static PyObject *
-psutil_users(PyObject *self, PyObject *args)
-{
+psutil_users(PyObject *self, PyObject *args) {
     PyObject *ret_list = PyList_New(0);
     PyObject *tuple = NULL;
     PyObject *user_proc = NULL;
@@ -472,12 +468,92 @@ error:
 }
 
 
+/*
+ * Return stats about a particular network
+ * interface.  References:
+ * https://github.com/dpaleino/wicd/blob/master/wicd/backends/be-ioctl.py
+ * http://www.i-scream.org/libstatgrab/
+ */
+static PyObject*
+psutil_net_if_stats(PyObject* self, PyObject* args) {
+    char *nic_name;
+    int sock = 0;
+    int ret;
+    int duplex;
+    int speed;
+    int mtu;
+    struct ifreq ifr;
+    struct ethtool_cmd ethcmd;
+    PyObject *py_is_up = NULL;
+    PyObject *py_ret = NULL;
+
+    if (! PyArg_ParseTuple(args, "s", &nic_name))
+        return NULL;
+
+    sock = socket(AF_INET, SOCK_DGRAM, 0);
+    if (sock == -1)
+        goto error;
+    strncpy(ifr.ifr_name, nic_name, sizeof(ifr.ifr_name));
+
+    // is up?
+    ret = ioctl(sock, SIOCGIFFLAGS, &ifr);
+    if (ret == -1)
+        goto error;
+    if ((ifr.ifr_flags & IFF_UP) != 0)
+        py_is_up = Py_True;
+    else
+        py_is_up = Py_False;
+    Py_INCREF(py_is_up);
+
+    // MTU
+    ret = ioctl(sock, SIOCGIFMTU, &ifr);
+    if (ret == -1)
+        goto error;
+    mtu = ifr.ifr_mtu;
+
+    // duplex and speed
+    memset(&ethcmd, 0, sizeof ethcmd);
+    ethcmd.cmd = ETHTOOL_GSET;
+    ifr.ifr_data = (void *)&ethcmd;
+    ret = ioctl(sock, SIOCETHTOOL, &ifr);
+
+    if (ret != -1) {
+        duplex = ethcmd.duplex;
+        speed = ethcmd.speed;
+    }
+    else {
+        if (errno == EOPNOTSUPP) {
+            // we typically get here in case of wi-fi cards
+            duplex = DUPLEX_UNKNOWN;
+            speed = 0;
+        }
+        else {
+            goto error;
+        }
+    }
+
+    close(sock);
+    py_ret = Py_BuildValue("[Oiii]", py_is_up, duplex, speed, mtu);
+    if (!py_ret)
+        goto error;
+    Py_DECREF(py_is_up);
+    return py_ret;
+
+error:
+    Py_XDECREF(py_is_up);
+    if (sock != 0)
+        close(sock);
+    PyErr_SetFromErrno(PyExc_OSError);
+    return NULL;
+}
+
+
 /*
  * Define the psutil C module methods and initialize the module.
  */
 static PyMethodDef
-PsutilMethods[] =
-{
+PsutilMethods[] = {
+
     // --- per-process functions
 
 #if PSUTIL_HAVE_IOPRIO
@@ -498,6 +574,8 @@ PsutilMethods[] =
      "device, mount point and filesystem type"},
     {"users", psutil_users, METH_VARARGS,
      "Return currently connected users as a list of tuples"},
+    {"net_if_stats", psutil_net_if_stats, METH_VARARGS,
+     "Return NIC stats (isup, duplex, speed, mtu)"},
 
     // --- linux specific
 
@@ -559,16 +637,15 @@ PyMODINIT_FUNC PyInit__psutil_linux(void)
 void init_psutil_linux(void)
 #endif
 {
+    PyObject *v;
 #if PY_MAJOR_VERSION >= 3
     PyObject *module = PyModule_Create(&moduledef);
 #else
     PyObject *module = Py_InitModule("_psutil_linux", PsutilMethods);
 #endif
 
-
     PyModule_AddIntConstant(module, "version", PSUTIL_VERSION);
 #if PSUTIL_HAVE_PRLIMIT
-    PyModule_AddIntConstant(module, "RLIM_INFINITY", RLIM_INFINITY);
     PyModule_AddIntConstant(module, "RLIMIT_AS", RLIMIT_AS);
     PyModule_AddIntConstant(module, "RLIMIT_CORE", RLIMIT_CORE);
     PyModule_AddIntConstant(module, "RLIMIT_CPU", RLIMIT_CPU);
@@ -580,6 +657,19 @@ void init_psutil_linux(void)
     PyModule_AddIntConstant(module, "RLIMIT_NPROC", RLIMIT_NPROC);
     PyModule_AddIntConstant(module, "RLIMIT_RSS", RLIMIT_RSS);
     PyModule_AddIntConstant(module, "RLIMIT_STACK", RLIMIT_STACK);
+
+#if defined(HAVE_LONG_LONG)
+    if (sizeof(RLIM_INFINITY) > sizeof(long)) {
+        v = PyLong_FromLongLong((PY_LONG_LONG) RLIM_INFINITY);
+    } else
+#endif
+    {
+        v = PyLong_FromLong((long) RLIM_INFINITY);
+    }
+    if (v) {
+        PyModule_AddObject(module, "RLIM_INFINITY", v);
+    }
+
 #ifdef RLIMIT_MSGQUEUE
     PyModule_AddIntConstant(module, "RLIMIT_MSGQUEUE", RLIMIT_MSGQUEUE);
 #endif
@@ -596,10 +686,12 @@ void init_psutil_linux(void)
     PyModule_AddIntConstant(module, "RLIMIT_SIGPENDING", RLIMIT_SIGPENDING);
 #endif
 #endif
+    PyModule_AddIntConstant(module, "DUPLEX_HALF", DUPLEX_HALF);
+    PyModule_AddIntConstant(module, "DUPLEX_FULL", DUPLEX_FULL);
+    PyModule_AddIntConstant(module, "DUPLEX_UNKNOWN", DUPLEX_UNKNOWN);
 
-    if (module == NULL) {
+    if (module == NULL)
         INITERROR;
-    }
 #if PY_MAJOR_VERSION >= 3
     return module;
 #endif
