@@ -48,8 +48,7 @@
  * A wrapper around host_statistics() invoked with HOST_VM_INFO.
  */
 int
-psutil_sys_vminfo(vm_statistics_data_t *vmstat)
-{
+psutil_sys_vminfo(vm_statistics_data_t *vmstat) {
     kern_return_t ret;
     mach_msg_type_number_t count = sizeof(*vmstat) / sizeof(integer_t);
     mach_port_t mport = mach_host_self();
@@ -69,8 +68,7 @@ psutil_sys_vminfo(vm_statistics_data_t *vmstat)
  * Return a Python list of all the PIDs running on the system.
  */
 static PyObject *
-psutil_pids(PyObject *self, PyObject *args)
-{
+psutil_pids(PyObject *self, PyObject *args) {
     kinfo_proc *proclist = NULL;
     kinfo_proc *orig_address = NULL;
     size_t num_processes;
@@ -116,16 +114,13 @@ error:
  * Return process name from kinfo_proc as a Python string.
  */
 static PyObject *
-psutil_proc_name(PyObject *self, PyObject *args)
-{
+psutil_proc_name(PyObject *self, PyObject *args) {
     long pid;
     struct kinfo_proc kp;
-    if (! PyArg_ParseTuple(args, "l", &pid)) {
+    if (! PyArg_ParseTuple(args, "l", &pid))
         return NULL;
-    }
-    if (psutil_get_kinfo_proc(pid, &kp) == -1) {
+    if (psutil_get_kinfo_proc(pid, &kp) == -1)
         return NULL;
-    }
     return Py_BuildValue("s", kp.kp_proc.p_comm);
 }
 
@@ -134,14 +129,12 @@ psutil_proc_name(PyObject *self, PyObject *args)
  * Return process current working directory.
  */
 static PyObject *
-psutil_proc_cwd(PyObject *self, PyObject *args)
-{
+psutil_proc_cwd(PyObject *self, PyObject *args) {
     long pid;
     struct proc_vnodepathinfo pathinfo;
 
-    if (! PyArg_ParseTuple(args, "l", &pid)) {
+    if (! PyArg_ParseTuple(args, "l", &pid))
         return NULL;
-    }
 
     if (! psutil_proc_pidinfo(pid, PROC_PIDVNODEPATHINFO, &pathinfo,
                               sizeof(pathinfo)))
@@ -156,23 +149,19 @@ psutil_proc_cwd(PyObject *self, PyObject *args)
  * Return path of the process executable.
  */
 static PyObject *
-psutil_proc_exe(PyObject *self, PyObject *args)
-{
+psutil_proc_exe(PyObject *self, PyObject *args) {
     long pid;
     char buf[PATH_MAX];
     int ret;
 
-    if (! PyArg_ParseTuple(args, "l", &pid)) {
+    if (! PyArg_ParseTuple(args, "l", &pid))
         return NULL;
-    }
     ret = proc_pidpath(pid, &buf, sizeof(buf));
     if (ret == 0) {
-        if (! psutil_pid_exists(pid)) {
+        if (! psutil_pid_exists(pid))
             return NoSuchProcess();
-        }
-        else {
+        else
             return AccessDenied();
-        }
     }
     return Py_BuildValue("s", buf);
 }
@@ -182,14 +171,12 @@ psutil_proc_exe(PyObject *self, PyObject *args)
  * Return process cmdline as a Python list of cmdline arguments.
  */
 static PyObject *
-psutil_proc_cmdline(PyObject *self, PyObject *args)
-{
+psutil_proc_cmdline(PyObject *self, PyObject *args) {
     long pid;
     PyObject *arglist = NULL;
 
-    if (! PyArg_ParseTuple(args, "l", &pid)) {
+    if (! PyArg_ParseTuple(args, "l", &pid))
         return NULL;
-    }
 
     // get the commandline, defined in arch/osx/process_info.c
     arglist = psutil_get_arg_list(pid);
@@ -201,16 +188,13 @@ psutil_proc_cmdline(PyObject *self, PyObject *args)
  * Return process parent pid from kinfo_proc as a Python integer.
  */
 static PyObject *
-psutil_proc_ppid(PyObject *self, PyObject *args)
-{
+psutil_proc_ppid(PyObject *self, PyObject *args) {
     long pid;
     struct kinfo_proc kp;
-    if (! PyArg_ParseTuple(args, "l", &pid)) {
+    if (! PyArg_ParseTuple(args, "l", &pid))
         return NULL;
-    }
-    if (psutil_get_kinfo_proc(pid, &kp) == -1) {
+    if (psutil_get_kinfo_proc(pid, &kp) == -1)
         return NULL;
-    }
     return Py_BuildValue("l", (long)kp.kp_eproc.e_ppid);
 }
 
@@ -219,16 +203,13 @@ psutil_proc_ppid(PyObject *self, PyObject *args)
  * Return process real uid from kinfo_proc as a Python integer.
  */
 static PyObject *
-psutil_proc_uids(PyObject *self, PyObject *args)
-{
+psutil_proc_uids(PyObject *self, PyObject *args) {
     long pid;
     struct kinfo_proc kp;
-    if (! PyArg_ParseTuple(args, "l", &pid)) {
+    if (! PyArg_ParseTuple(args, "l", &pid))
         return NULL;
-    }
-    if (psutil_get_kinfo_proc(pid, &kp) == -1) {
+    if (psutil_get_kinfo_proc(pid, &kp) == -1)
         return NULL;
-    }
     return Py_BuildValue("lll",
                          (long)kp.kp_eproc.e_pcred.p_ruid,
                          (long)kp.kp_eproc.e_ucred.cr_uid,
@@ -240,16 +221,13 @@ psutil_proc_uids(PyObject *self, PyObject *args)
  * Return process real group id from ki_comm as a Python integer.
  */
 static PyObject *
-psutil_proc_gids(PyObject *self, PyObject *args)
-{
+psutil_proc_gids(PyObject *self, PyObject *args) {
     long pid;
     struct kinfo_proc kp;
-    if (! PyArg_ParseTuple(args, "l", &pid)) {
+    if (! PyArg_ParseTuple(args, "l", &pid))
         return NULL;
-    }
-    if (psutil_get_kinfo_proc(pid, &kp) == -1) {
+    if (psutil_get_kinfo_proc(pid, &kp) == -1)
         return NULL;
-    }
     return Py_BuildValue("lll",
                          (long)kp.kp_eproc.e_pcred.p_rgid,
                          (long)kp.kp_eproc.e_ucred.cr_groups[0],
@@ -261,16 +239,13 @@ psutil_proc_gids(PyObject *self, PyObject *args)
  * Return process controlling terminal number as an integer.
  */
 static PyObject *
-psutil_proc_tty_nr(PyObject *self, PyObject *args)
-{
+psutil_proc_tty_nr(PyObject *self, PyObject *args) {
     long pid;
     struct kinfo_proc kp;
-    if (! PyArg_ParseTuple(args, "l", &pid)) {
+    if (! PyArg_ParseTuple(args, "l", &pid))
         return NULL;
-    }
-    if (psutil_get_kinfo_proc(pid, &kp) == -1) {
+    if (psutil_get_kinfo_proc(pid, &kp) == -1)
         return NULL;
-    }
     return Py_BuildValue("i", kp.kp_eproc.e_tdev);
 }
 
@@ -280,8 +255,7 @@ psutil_proc_tty_nr(PyObject *self, PyObject *args)
  * 'procstat' cmdline utility has been used as an example.
  */
 static PyObject *
-psutil_proc_memory_maps(PyObject *self, PyObject *args)
-{
+psutil_proc_memory_maps(PyObject *self, PyObject *args) {
     char buf[PATH_MAX];
     char addr_str[34];
     char perms[8];
@@ -299,9 +273,8 @@ psutil_proc_memory_maps(PyObject *self, PyObject *args)
     if (py_list == NULL)
         return NULL;
 
-    if (! PyArg_ParseTuple(args, "l", &pid)) {
+    if (! PyArg_ParseTuple(args, "l", &pid))
         goto error;
-    }
 
     err = task_for_pid(mach_task_self(), pid, &task);
 
@@ -324,11 +297,8 @@ psutil_proc_memory_maps(PyObject *self, PyObject *args)
 
         err = vm_region_recurse_64(task, &address, &size, &depth,
                                    (vm_region_info_64_t)&info, &count);
-
-        if (err == KERN_INVALID_ADDRESS) {
+        if (err == KERN_INVALID_ADDRESS)
             break;
-        }
-
         if (info.is_submap) {
             depth++;
         }
@@ -356,32 +326,30 @@ psutil_proc_memory_maps(PyObject *self, PyObject *args)
 
             if (strlen(buf) == 0) {
                 switch (info.share_mode) {
-                /*
-                case SM_LARGE_PAGE:
-                    // Treat SM_LARGE_PAGE the same as SM_PRIVATE
-                    // since they are not shareable and are wired.
-                */
-                case SM_COW:
-                    strcpy(buf, "[cow]");
-                    break;
-                case SM_PRIVATE:
-                    strcpy(buf, "[prv]");
-                    break;
-                case SM_EMPTY:
-                    strcpy(buf, "[nul]");
-                    break;
-                case SM_SHARED:
-                case SM_TRUESHARED:
-                    strcpy(buf, "[shm]");
-                    break;
-                case SM_PRIVATE_ALIASED:
-                    strcpy(buf, "[ali]");
-                    break;
-                case SM_SHARED_ALIASED:
-                    strcpy(buf, "[s/a]");
-                    break;
-                default:
-                    strcpy(buf, "[???]");
+                    // case SM_LARGE_PAGE:
+                        // Treat SM_LARGE_PAGE the same as SM_PRIVATE
+                        // since they are not shareable and are wired.
+                    case SM_COW:
+                        strcpy(buf, "[cow]");
+                        break;
+                    case SM_PRIVATE:
+                        strcpy(buf, "[prv]");
+                        break;
+                    case SM_EMPTY:
+                        strcpy(buf, "[nul]");
+                        break;
+                    case SM_SHARED:
+                    case SM_TRUESHARED:
+                        strcpy(buf, "[shm]");
+                        break;
+                    case SM_PRIVATE_ALIASED:
+                        strcpy(buf, "[ali]");
+                        break;
+                    case SM_SHARED_ALIASED:
+                        strcpy(buf, "[s/a]");
+                        break;
+                    default:
+                        strcpy(buf, "[???]");
                 }
             }
 
@@ -427,23 +395,27 @@ error:
  * XXX this could be shared with BSD.
  */
 static PyObject *
-psutil_cpu_count_logical(PyObject *self, PyObject *args)
-{
+psutil_cpu_count_logical(PyObject *self, PyObject *args) {
+    /*
     int mib[2];
     int ncpu;
     size_t len;
-
     mib[0] = CTL_HW;
     mib[1] = HW_NCPU;
     len = sizeof(ncpu);
 
-    if (sysctl(mib, 2, &ncpu, &len, NULL, 0) == -1) {
-        // mimic os.cpu_count()
-        Py_RETURN_NONE;
-    }
-    else {
+    if (sysctl(mib, 2, &ncpu, &len, NULL, 0) == -1)
+        Py_RETURN_NONE;  // mimic os.cpu_count()
+    else
         return Py_BuildValue("i", ncpu);
-    }
+    */
+    int num;
+    size_t size = sizeof(int);
+
+    if (sysctlbyname("hw.logicalcpu", &num, &size, NULL, 2))
+        Py_RETURN_NONE;  // mimic os.cpu_count()
+    else
+        return Py_BuildValue("i", num);
 }
 
 
@@ -451,15 +423,14 @@ psutil_cpu_count_logical(PyObject *self, PyObject *args)
  * Return the number of physical CPUs in the system.
  */
 static PyObject *
-psutil_cpu_count_phys(PyObject *self, PyObject *args)
-{
+psutil_cpu_count_phys(PyObject *self, PyObject *args) {
     int num;
     size_t size = sizeof(int);
-    if (sysctlbyname("hw.physicalcpu", &num, &size, NULL, 0)) {
-        // mimic os.cpu_count()
-        Py_RETURN_NONE;
-    }
-    return Py_BuildValue("i", num);
+
+    if (sysctlbyname("hw.physicalcpu", &num, &size, NULL, 0))
+        Py_RETURN_NONE;  // mimic os.cpu_count()
+    else
+        return Py_BuildValue("i", num);
 }
 
 
@@ -469,16 +440,14 @@ psutil_cpu_count_phys(PyObject *self, PyObject *args)
  * Return a Python tuple (user_time, kernel_time)
  */
 static PyObject *
-psutil_proc_cpu_times(PyObject *self, PyObject *args)
-{
+psutil_proc_cpu_times(PyObject *self, PyObject *args) {
     long pid;
     struct proc_taskinfo pti;
-    if (! PyArg_ParseTuple(args, "l", &pid)) {
+
+    if (! PyArg_ParseTuple(args, "l", &pid))
         return NULL;
-    }
-    if (! psutil_proc_pidinfo(pid, PROC_PIDTASKINFO, &pti, sizeof(pti))) {
+    if (! psutil_proc_pidinfo(pid, PROC_PIDTASKINFO, &pti, sizeof(pti)))
         return NULL;
-    }
     return Py_BuildValue("(dd)",
                          (float)pti.pti_total_user / 1000000000.0,
                          (float)pti.pti_total_system / 1000000000.0);
@@ -490,16 +459,13 @@ psutil_proc_cpu_times(PyObject *self, PyObject *args)
  * seconds since the epoch.
  */
 static PyObject *
-psutil_proc_create_time(PyObject *self, PyObject *args)
-{
+psutil_proc_create_time(PyObject *self, PyObject *args) {
     long pid;
     struct kinfo_proc kp;
-    if (! PyArg_ParseTuple(args, "l", &pid)) {
+    if (! PyArg_ParseTuple(args, "l", &pid))
         return NULL;
-    }
-    if (psutil_get_kinfo_proc(pid, &kp) == -1) {
+    if (psutil_get_kinfo_proc(pid, &kp) == -1)
         return NULL;
-    }
     return Py_BuildValue("d", TV2DOUBLE(kp.kp_proc.p_starttime));
 }
 
@@ -508,17 +474,14 @@ psutil_proc_create_time(PyObject *self, PyObject *args)
  * Return extended memory info about a process.
  */
 static PyObject *
-psutil_proc_memory_info(PyObject *self, PyObject *args)
-{
+psutil_proc_memory_info(PyObject *self, PyObject *args) {
     long pid;
     struct proc_taskinfo pti;
-    if (! PyArg_ParseTuple(args, "l", &pid)) {
-        return NULL;
-    }
-    if (! psutil_proc_pidinfo(pid, PROC_PIDTASKINFO, &pti, sizeof(pti))) {
-        return NULL;
-    }
 
+    if (! PyArg_ParseTuple(args, "l", &pid))
+        return NULL;
+    if (! psutil_proc_pidinfo(pid, PROC_PIDTASKINFO, &pti, sizeof(pti)))
+        return NULL;
     // Note: determining other memory stats on OSX is a mess:
     // http://www.opensource.apple.com/source/top/top-67/libtop.c?txt
     // I just give up...
@@ -538,16 +501,14 @@ psutil_proc_memory_info(PyObject *self, PyObject *args)
  * Return number of threads used by process as a Python integer.
  */
 static PyObject *
-psutil_proc_num_threads(PyObject *self, PyObject *args)
-{
+psutil_proc_num_threads(PyObject *self, PyObject *args) {
     long pid;
     struct proc_taskinfo pti;
-    if (! PyArg_ParseTuple(args, "l", &pid)) {
+
+    if (! PyArg_ParseTuple(args, "l", &pid))
         return NULL;
-    }
-    if (! psutil_proc_pidinfo(pid, PROC_PIDTASKINFO, &pti, sizeof(pti))) {
+    if (! psutil_proc_pidinfo(pid, PROC_PIDTASKINFO, &pti, sizeof(pti)))
         return NULL;
-    }
     return Py_BuildValue("k", pti.pti_threadnum);
 }
 
@@ -556,16 +517,14 @@ psutil_proc_num_threads(PyObject *self, PyObject *args)
  * Return the number of context switches performed by process.
  */
 static PyObject *
-psutil_proc_num_ctx_switches(PyObject *self, PyObject *args)
-{
+psutil_proc_num_ctx_switches(PyObject *self, PyObject *args) {
     long pid;
     struct proc_taskinfo pti;
-    if (! PyArg_ParseTuple(args, "l", &pid)) {
+
+    if (! PyArg_ParseTuple(args, "l", &pid))
         return NULL;
-    }
-    if (! psutil_proc_pidinfo(pid, PROC_PIDTASKINFO, &pti, sizeof(pti))) {
+    if (! psutil_proc_pidinfo(pid, PROC_PIDTASKINFO, &pti, sizeof(pti)))
         return NULL;
-    }
     // unvoluntary value seems not to be available;
     // pti.pti_csw probably refers to the sum of the two (getrusage()
     // numbers seems to confirm this theory).
@@ -577,18 +536,18 @@ psutil_proc_num_ctx_switches(PyObject *self, PyObject *args)
  * Return system virtual memory stats
  */
 static PyObject *
-psutil_virtual_mem(PyObject *self, PyObject *args)
-{
+psutil_virtual_mem(PyObject *self, PyObject *args) {
 
     int      mib[2];
     uint64_t total;
     size_t   len = sizeof(total);
     vm_statistics_data_t vm;
     int pagesize = getpagesize();
-
     // physical mem
     mib[0] = CTL_HW;
     mib[1] = HW_MEMSIZE;
+
+    // This is also available as sysctlbyname("hw.memsize").
     if (sysctl(mib, 2, &total, &len, NULL, 0)) {
         if (errno != 0)
             PyErr_SetFromErrno(PyExc_OSError);
@@ -598,9 +557,8 @@ psutil_virtual_mem(PyObject *self, PyObject *args)
     }
 
     // vm
-    if (!psutil_sys_vminfo(&vm)) {
+    if (!psutil_sys_vminfo(&vm))
         return NULL;
-    }
 
     return Py_BuildValue(
         "KKKKK",
@@ -617,8 +575,7 @@ psutil_virtual_mem(PyObject *self, PyObject *args)
  * Return stats about swap memory.
  */
 static PyObject *
-psutil_swap_mem(PyObject *self, PyObject *args)
-{
+psutil_swap_mem(PyObject *self, PyObject *args) {
     int mib[2];
     size_t size;
     struct xsw_usage totals;
@@ -635,9 +592,8 @@ psutil_swap_mem(PyObject *self, PyObject *args)
             PyErr_Format(PyExc_RuntimeError, "sysctl(VM_SWAPUSAGE) failed");
         return NULL;
     }
-    if (!psutil_sys_vminfo(&vmstat)) {
+    if (!psutil_sys_vminfo(&vmstat))
         return NULL;
-    }
 
     return Py_BuildValue(
         "LLLKK",
@@ -653,8 +609,7 @@ psutil_swap_mem(PyObject *self, PyObject *args)
  * Return a Python tuple representing user, kernel and idle CPU times
  */
 static PyObject *
-psutil_cpu_times(PyObject *self, PyObject *args)
-{
+psutil_cpu_times(PyObject *self, PyObject *args) {
     mach_msg_type_number_t count = HOST_CPU_LOAD_INFO_COUNT;
     kern_return_t error;
     host_cpu_load_info_data_t r_load;
@@ -662,11 +617,10 @@ psutil_cpu_times(PyObject *self, PyObject *args)
     mach_port_t host_port = mach_host_self();
     error = host_statistics(host_port, HOST_CPU_LOAD_INFO,
                             (host_info_t)&r_load, &count);
-    if (error != KERN_SUCCESS) {
+    if (error != KERN_SUCCESS)
         return PyErr_Format(PyExc_RuntimeError,
                             "Error in host_statistics(): %s",
                             mach_error_string(error));
-    }
     mach_port_deallocate(mach_task_self(), host_port);
 
     return Py_BuildValue(
@@ -683,8 +637,7 @@ psutil_cpu_times(PyObject *self, PyObject *args)
  * Return a Python list of tuple representing per-cpu times
  */
 static PyObject *
-psutil_per_cpu_times(PyObject *self, PyObject *args)
-{
+psutil_per_cpu_times(PyObject *self, PyObject *args) {
     natural_t cpu_count;
     processor_info_array_t info_array;
     mach_msg_type_number_t info_count;
@@ -726,9 +679,8 @@ psutil_per_cpu_times(PyObject *self, PyObject *args)
 
     ret = vm_deallocate(mach_task_self(), (vm_address_t)info_array,
                         info_count * sizeof(int));
-    if (ret != KERN_SUCCESS) {
+    if (ret != KERN_SUCCESS)
         PyErr_WarnEx(PyExc_RuntimeWarning, "vm_deallocate() failed", 2);
-    }
     return py_retlist;
 
 error:
@@ -737,9 +689,8 @@ error:
     if (cpu_load_info != NULL) {
         ret = vm_deallocate(mach_task_self(), (vm_address_t)info_array,
                             info_count * sizeof(int));
-        if (ret != KERN_SUCCESS) {
+        if (ret != KERN_SUCCESS)
             PyErr_WarnEx(PyExc_RuntimeWarning, "vm_deallocate() failed", 2);
-        }
     }
     return NULL;
 }
@@ -750,8 +701,7 @@ error:
  * seconds since the epoch.
  */
 static PyObject *
-psutil_boot_time(PyObject *self, PyObject *args)
-{
+psutil_boot_time(PyObject *self, PyObject *args) {
     // fetch sysctl "kern.boottime"
     static int request[2] = { CTL_KERN, KERN_BOOTTIME };
     struct timeval result;
@@ -772,8 +722,7 @@ psutil_boot_time(PyObject *self, PyObject *args)
  * for all partitions mounted on the system.
  */
 static PyObject *
-psutil_disk_partitions(PyObject *self, PyObject *args)
-{
+psutil_disk_partitions(PyObject *self, PyObject *args) {
     int num;
     int i;
     long len;
@@ -894,16 +843,13 @@ error:
  * Return process status as a Python integer.
  */
 static PyObject *
-psutil_proc_status(PyObject *self, PyObject *args)
-{
+psutil_proc_status(PyObject *self, PyObject *args) {
     long pid;
     struct kinfo_proc kp;
-    if (! PyArg_ParseTuple(args, "l", &pid)) {
+    if (! PyArg_ParseTuple(args, "l", &pid))
         return NULL;
-    }
-    if (psutil_get_kinfo_proc(pid, &kp) == -1) {
+    if (psutil_get_kinfo_proc(pid, &kp) == -1)
         return NULL;
-    }
     return Py_BuildValue("i", (int)kp.kp_proc.p_stat);
 }
 
@@ -912,8 +858,7 @@ psutil_proc_status(PyObject *self, PyObject *args)
  * Return process threads
  */
 static PyObject *
-psutil_proc_threads(PyObject *self, PyObject *args)
-{
+psutil_proc_threads(PyObject *self, PyObject *args) {
     long pid;
     int err, j, ret;
     kern_return_t kr;
@@ -932,19 +877,16 @@ psutil_proc_threads(PyObject *self, PyObject *args)
         return NULL;
 
     // the argument passed should be a process id
-    if (! PyArg_ParseTuple(args, "l", &pid)) {
+    if (! PyArg_ParseTuple(args, "l", &pid))
         goto error;
-    }
 
     // task_for_pid() requires special privileges
     err = task_for_pid(mach_task_self(), pid, &task);
     if (err != KERN_SUCCESS) {
-        if (! psutil_pid_exists(pid)) {
+        if (! psutil_pid_exists(pid))
             NoSuchProcess();
-        }
-        else {
+        else
             AccessDenied();
-        }
         goto error;
     }
 
@@ -997,9 +939,8 @@ psutil_proc_threads(PyObject *self, PyObject *args)
 
     ret = vm_deallocate(task, (vm_address_t)thread_list,
                         thread_count * sizeof(int));
-    if (ret != KERN_SUCCESS) {
+    if (ret != KERN_SUCCESS)
         PyErr_WarnEx(PyExc_RuntimeWarning, "vm_deallocate() failed", 2);
-    }
 
     mach_port_deallocate(mach_task_self(), task);
 
@@ -1013,9 +954,8 @@ error:
     if (thread_list != NULL) {
         ret = vm_deallocate(task, (vm_address_t)thread_list,
                             thread_count * sizeof(int));
-        if (ret != KERN_SUCCESS) {
+        if (ret != KERN_SUCCESS)
             PyErr_WarnEx(PyExc_RuntimeWarning, "vm_deallocate() failed", 2);
-        }
     }
     return NULL;
 }
@@ -1028,8 +968,7 @@ error:
  * - /usr/include/sys/proc_info.h
  */
 static PyObject *
-psutil_proc_open_files(PyObject *self, PyObject *args)
-{
+psutil_proc_open_files(PyObject *self, PyObject *args) {
     long pid;
     int pidinfo_result;
     int iterations;
@@ -1046,9 +985,8 @@ psutil_proc_open_files(PyObject *self, PyObject *args)
     if (retList == NULL)
         return NULL;
 
-    if (! PyArg_ParseTuple(args, "l", &pid)) {
+    if (! PyArg_ParseTuple(args, "l", &pid))
         goto error;
-    }
 
     pidinfo_result = proc_pidinfo(pid, PROC_PIDLISTFDS, 0, NULL, 0);
     if (pidinfo_result <= 0) {
@@ -1125,19 +1063,14 @@ psutil_proc_open_files(PyObject *self, PyObject *args)
 error:
     Py_XDECREF(tuple);
     Py_DECREF(retList);
-    if (fds_pointer != NULL) {
+    if (fds_pointer != NULL)
         free(fds_pointer);
-    }
-    if (errno != 0) {
+    if (errno != 0)
         return PyErr_SetFromErrno(PyExc_OSError);
-    }
-    else if (! psutil_pid_exists(pid)) {
+    else if (! psutil_pid_exists(pid))
         return NoSuchProcess();
-    }
-    else {
-        // exception has already been set earlier
-        return NULL;
-    }
+    else
+        return NULL;  // exception has already been set earlier
 }
 
 
@@ -1151,8 +1084,7 @@ static int PSUTIL_CONN_NONE = 128;
  * - /usr/include/sys/proc_info.h
  */
 static PyObject *
-psutil_proc_connections(PyObject *self, PyObject *args)
-{
+psutil_proc_connections(PyObject *self, PyObject *args) {
     long pid;
     int pidinfo_result;
     int iterations;
@@ -1173,23 +1105,19 @@ psutil_proc_connections(PyObject *self, PyObject *args)
     if (retList == NULL)
         return NULL;
 
-    if (! PyArg_ParseTuple(args, "lOO", &pid, &af_filter, &type_filter)) {
+    if (! PyArg_ParseTuple(args, "lOO", &pid, &af_filter, &type_filter))
         goto error;
-    }
 
     if (!PySequence_Check(af_filter) || !PySequence_Check(type_filter)) {
         PyErr_SetString(PyExc_TypeError, "arg 2 or 3 is not a sequence");
         goto error;
     }
 
-    if (pid == 0) {
+    if (pid == 0)
         return retList;
-    }
-
     pidinfo_result = proc_pidinfo(pid, PROC_PIDLISTFDS, 0, NULL, 0);
-    if (pidinfo_result <= 0) {
+    if (pidinfo_result <= 0)
         goto error;
-    }
 
     fds_pointer = malloc(pidinfo_result);
     if (fds_pointer == NULL) {
@@ -1199,10 +1127,8 @@ psutil_proc_connections(PyObject *self, PyObject *args)
     pidinfo_result = proc_pidinfo(pid, PROC_PIDLISTFDS, 0, fds_pointer,
                                   pidinfo_result);
 
-    if (pidinfo_result <= 0) {
+    if (pidinfo_result <= 0)
         goto error;
-    }
-
     iterations = (pidinfo_result / PROC_PIDLISTFD_SIZE);
 
     for (i = 0; i < iterations; i++) {
@@ -1223,14 +1149,12 @@ psutil_proc_connections(PyObject *self, PyObject *args)
                     // let's assume socket has been closed
                     continue;
                 }
-                if (errno != 0) {
+                if (errno != 0)
                     PyErr_SetFromErrno(PyExc_OSError);
-                }
-                else {
+                else
                     PyErr_Format(
                         PyExc_RuntimeError,
                         "proc_pidinfo(PROC_PIDFDVNODEPATHINFO) failed");
-                }
                 goto error;
             }
             if (nb < sizeof(si)) {
@@ -1256,15 +1180,13 @@ psutil_proc_connections(PyObject *self, PyObject *args)
             _family = PyLong_FromLong((long)family);
             inseq = PySequence_Contains(af_filter, _family);
             Py_DECREF(_family);
-            if (inseq == 0) {
+            if (inseq == 0)
                 continue;
-            }
             _type = PyLong_FromLong((long)type);
             inseq = PySequence_Contains(type_filter, _type);
             Py_DECREF(_type);
-            if (inseq == 0) {
+            if (inseq == 0)
                 continue;
-            }
 
             if (errno != 0) {
                 PyErr_SetFromErrno(PyExc_OSError);
@@ -1303,22 +1225,18 @@ psutil_proc_connections(PyObject *self, PyObject *args)
 
                 lport = ntohs(si.psi.soi_proto.pri_tcp.tcpsi_ini.insi_lport);
                 rport = ntohs(si.psi.soi_proto.pri_tcp.tcpsi_ini.insi_fport);
-                if (type == SOCK_STREAM) {
+                if (type == SOCK_STREAM)
                     state = (int)si.psi.soi_proto.pri_tcp.tcpsi_state;
-                }
-                else {
+                else
                     state = PSUTIL_CONN_NONE;
-                }
 
                 laddr = Py_BuildValue("(si)", lip, lport);
                 if (!laddr)
                     goto error;
-                if (rport != 0) {
+                if (rport != 0)
                     raddr = Py_BuildValue("(si)", rip, rport);
-                }
-                else {
+                else
                     raddr = Py_BuildValue("()");
-                }
                 if (!raddr)
                     goto error;
 
@@ -1357,19 +1275,15 @@ error:
     Py_XDECREF(raddr);
     Py_DECREF(retList);
 
-    if (fds_pointer != NULL) {
+    if (fds_pointer != NULL)
         free(fds_pointer);
-    }
-    if (errno != 0) {
+    if (errno != 0)
         return PyErr_SetFromErrno(PyExc_OSError);
-    }
-    else if (! psutil_pid_exists(pid) ) {
+    else if (! psutil_pid_exists(pid))
         return NoSuchProcess();
-    }
-    else {
+    else
         return PyErr_Format(PyExc_RuntimeError,
                             "proc_pidinfo(PROC_PIDLISTFDS) failed");
-    }
 }
 
 
@@ -1377,26 +1291,22 @@ error:
  * Return number of file descriptors opened by process.
  */
 static PyObject *
-psutil_proc_num_fds(PyObject *self, PyObject *args)
-{
+psutil_proc_num_fds(PyObject *self, PyObject *args) {
     long pid;
     int pidinfo_result;
     int num;
     struct proc_fdinfo *fds_pointer;
 
-    if (! PyArg_ParseTuple(args, "l", &pid)) {
+    if (! PyArg_ParseTuple(args, "l", &pid))
         return NULL;
-    }
 
     pidinfo_result = proc_pidinfo(pid, PROC_PIDLISTFDS, 0, NULL, 0);
-    if (pidinfo_result <= 0) {
+    if (pidinfo_result <= 0)
         return PyErr_SetFromErrno(PyExc_OSError);
-    }
 
     fds_pointer = malloc(pidinfo_result);
-    if (fds_pointer == NULL) {
+    if (fds_pointer == NULL)
         return PyErr_NoMemory();
-    }
     pidinfo_result = proc_pidinfo(pid, PROC_PIDLISTFDS, 0, fds_pointer,
                                   pidinfo_result);
     if (pidinfo_result <= 0) {
@@ -1414,8 +1324,7 @@ psutil_proc_num_fds(PyObject *self, PyObject *args)
  * Return a Python list of named tuples with overall network I/O information
  */
 static PyObject *
-psutil_net_io_counters(PyObject *self, PyObject *args)
-{
+psutil_net_io_counters(PyObject *self, PyObject *args) {
     char *buf = NULL, *lim, *next;
     struct if_msghdr *ifm;
     int mib[6];
@@ -1502,8 +1411,7 @@ error:
  * Return a Python dict of tuples for disk I/O information
  */
 static PyObject *
-psutil_disk_io_counters(PyObject *self, PyObject *args)
-{
+psutil_disk_io_counters(PyObject *self, PyObject *args) {
     CFDictionaryRef parent_dict;
     CFDictionaryRef props_dict;
     CFDictionaryRef stats_dict;
@@ -1677,8 +1585,7 @@ error:
  * Return currently connected users as a list of tuples.
  */
 static PyObject *
-psutil_users(PyObject *self, PyObject *args)
-{
+psutil_users(PyObject *self, PyObject *args) {
     struct utmpx *utx;
     PyObject *ret_list = PyList_New(0);
     PyObject *tuple = NULL;
@@ -1720,8 +1627,8 @@ error:
  * define the psutil C module methods and initialize the module.
  */
 static PyMethodDef
-PsutilMethods[] =
-{
+PsutilMethods[] = {
+
     // --- per-process functions
 
     {"proc_name", psutil_proc_name, METH_VARARGS,
@@ -1871,9 +1778,8 @@ init_psutil_osx(void)
     PyModule_AddIntConstant(module, "TCPS_TIME_WAIT", TCPS_TIME_WAIT);
     PyModule_AddIntConstant(module, "PSUTIL_CONN_NONE", PSUTIL_CONN_NONE);
 
-    if (module == NULL) {
+    if (module == NULL)
         INITERROR;
-    }
 #if PY_MAJOR_VERSION >= 3
     return module;
 #endif
