@@ -30,6 +30,8 @@
 #include <sys/mntent.h>  // for MNTTAB
 #include <sys/mnttab.h>
 #include <sys/procfs.h>
+#include <sys/sockio.h>
+#include <sys/socket.h>
 #include <fcntl.h>
 #include <utmpx.h>
 #include <kstat.h>
@@ -38,6 +40,7 @@
 #include <stropts.h>
 #include <inet/tcp.h>
 #include <arpa/inet.h>
+#include <net/if.h>
 
 #include "_psutil_sunos.h"
 
@@ -48,8 +51,7 @@
  * Read a file content and fills a C structure with it.
  */
 int
-psutil_file_to_struct(char *path, void *fstruct, size_t size)
-{
+psutil_file_to_struct(char *path, void *fstruct, size_t size) {
     int fd;
     size_t nbytes;
     fd = open(path, O_RDONLY);
@@ -78,8 +80,7 @@ psutil_file_to_struct(char *path, void *fstruct, size_t size)
  * as a Python tuple.
  */
 static PyObject *
-psutil_proc_basic_info(PyObject *self, PyObject *args)
-{
+psutil_proc_basic_info(PyObject *self, PyObject *args) {
     int pid;
     char path[100];
     psinfo_t info;
@@ -106,8 +107,7 @@ psutil_proc_basic_info(PyObject *self, PyObject *args)
  * Return process name and args as a Python tuple.
  */
 static PyObject *
-psutil_proc_name_and_args(PyObject *self, PyObject *args)
-{
+psutil_proc_name_and_args(PyObject *self, PyObject *args) {
     int pid;
     char path[100];
     psinfo_t info;
@@ -125,8 +125,7 @@ psutil_proc_name_and_args(PyObject *self, PyObject *args)
  * Return process user and system CPU times as a Python tuple.
  */
 static PyObject *
-psutil_proc_cpu_times(PyObject *self, PyObject *args)
-{
+psutil_proc_cpu_times(PyObject *self, PyObject *args) {
     int pid;
     char path[100];
     pstatus_t info;
@@ -147,8 +146,7 @@ psutil_proc_cpu_times(PyObject *self, PyObject *args)
  * Return process uids/gids as a Python tuple.
  */
 static PyObject *
-psutil_proc_cred(PyObject *self, PyObject *args)
-{
+psutil_proc_cred(PyObject *self, PyObject *args) {
     int pid;
     char path[100];
     prcred_t info;
@@ -168,8 +166,7 @@ psutil_proc_cred(PyObject *self, PyObject *args)
  * Return process uids/gids as a Python tuple.
  */
 static PyObject *
-psutil_proc_num_ctx_switches(PyObject *self, PyObject *args)
-{
+psutil_proc_num_ctx_switches(PyObject *self, PyObject *args) {
     int pid;
     char path[100];
     prusage_t info;
@@ -195,19 +192,16 @@ psutil_proc_num_ctx_switches(PyObject *self, PyObject *args)
  *    ...they should be meaningless anyway.
  *
 static PyObject*
-proc_io_counters(PyObject* self, PyObject* args)
-{
+proc_io_counters(PyObject* self, PyObject* args) {
     int pid;
     char path[100];
     prusage_t info;
 
-    if (! PyArg_ParseTuple(args, "i", &pid)) {
+    if (! PyArg_ParseTuple(args, "i", &pid))
         return NULL;
-    }
     sprintf(path, "/proc/%i/usage", pid);
-    if (! psutil_file_to_struct(path, (void *)&info, sizeof(info))) {
+    if (! psutil_file_to_struct(path, (void *)&info, sizeof(info)))
         return NULL;
-    }
 
     // On Solaris we only have 'pr_ioch' which accounts for bytes read
     // *and* written.
@@ -227,8 +221,7 @@ proc_io_counters(PyObject* self, PyObject* args)
  * Return information about a given process thread.
  */
 static PyObject *
-psutil_proc_query_thread(PyObject *self, PyObject *args)
-{
+psutil_proc_query_thread(PyObject *self, PyObject *args) {
     int pid, tid;
     char path[100];
     lwpstatus_t info;
@@ -248,8 +241,7 @@ psutil_proc_query_thread(PyObject *self, PyObject *args)
  * Return information about system virtual memory.
  */
 static PyObject *
-psutil_swap_mem(PyObject *self, PyObject *args)
-{
+psutil_swap_mem(PyObject *self, PyObject *args) {
 // XXX (arghhh!)
 // total/free swap mem: commented out as for some reason I can't
 // manage to get the same results shown by "swap -l", despite the
@@ -315,9 +307,8 @@ psutil_swap_mem(PyObject *self, PyObject *args)
     uint_t      sout = 0;
 
     kc = kstat_open();
-    if (kc == NULL) {
+    if (kc == NULL)
         return PyErr_SetFromErrno(PyExc_OSError);;
-    }
 
     k = kc->kc_chain;
     while (k != NULL) {
@@ -345,8 +336,7 @@ psutil_swap_mem(PyObject *self, PyObject *args)
  * Return users currently connected on the system.
  */
 static PyObject *
-psutil_users(PyObject *self, PyObject *args)
-{
+psutil_users(PyObject *self, PyObject *args) {
     struct utmpx *ut;
     PyObject *ret_list = PyList_New(0);
     PyObject *tuple = NULL;
@@ -391,8 +381,7 @@ error:
  * mount point and filesystem type.
  */
 static PyObject *
-psutil_disk_partitions(PyObject *self, PyObject *args)
-{
+psutil_disk_partitions(PyObject *self, PyObject *args) {
     FILE *file;
     struct mnttab mt;
     PyObject *py_retlist = PyList_New(0);
@@ -437,13 +426,10 @@ error:
  * Return system-wide CPU times.
  */
 static PyObject *
-psutil_per_cpu_times(PyObject *self, PyObject *args)
-{
+psutil_per_cpu_times(PyObject *self, PyObject *args) {
     kstat_ctl_t *kc;
     kstat_t *ksp;
     cpu_stat_t cs;
-    int numcpus;
-    int i;
     PyObject *py_retlist = PyList_New(0);
     PyObject *py_cputime = NULL;
 
@@ -492,8 +478,7 @@ error:
  * Return disk IO statistics.
  */
 static PyObject *
-psutil_disk_io_counters(PyObject *self, PyObject *args)
-{
+psutil_disk_io_counters(PyObject *self, PyObject *args) {
     kstat_ctl_t *kc;
     kstat_t *ksp;
     kstat_io_t kio;
@@ -551,8 +536,7 @@ error:
  * Return process memory mappings.
  */
 static PyObject *
-psutil_proc_memory_maps(PyObject *self, PyObject *args)
-{
+psutil_proc_memory_maps(PyObject *self, PyObject *args) {
     int pid;
     int fd = -1;
     char path[100];
@@ -571,17 +555,14 @@ psutil_proc_memory_maps(PyObject *self, PyObject *args)
     PyObject *pytuple = NULL;
     PyObject *py_retlist = PyList_New(0);
 
-    if (py_retlist == NULL) {
+    if (py_retlist == NULL)
         return NULL;
-    }
-    if (! PyArg_ParseTuple(args, "i", &pid)) {
+    if (! PyArg_ParseTuple(args, "i", &pid))
         goto error;
-    }
 
     sprintf(path, "/proc/%i/status", pid);
-    if (! psutil_file_to_struct(path, (void *)&status, sizeof(status))) {
+    if (! psutil_file_to_struct(path, (void *)&status, sizeof(status)))
         goto error;
-    }
 
     sprintf(path, "/proc/%i/xmap", pid);
     if (stat(path, &st) == -1) {
@@ -689,8 +670,7 @@ error:
  * Return a list of tuples for network I/O statistics.
  */
 static PyObject *
-psutil_net_io_counters(PyObject *self, PyObject *args)
-{
+psutil_net_io_counters(PyObject *self, PyObject *args) {
     kstat_ctl_t    *kc = NULL;
     kstat_t *ksp;
     kstat_named_t *rbytes, *wbytes, *rpkts, *wpkts, *ierrs, *oerrs;
@@ -717,9 +697,8 @@ psutil_net_io_counters(PyObject *self, PyObject *args)
             (strcmp(ksp->ks_module, "lo") != 0)) {
             goto skip;
         */
-        if ((strcmp(ksp->ks_module, "link") != 0)) {
+        if ((strcmp(ksp->ks_module, "link") != 0))
             goto next;
-        }
 
         if (kstat_read(kc, ksp, NULL) == -1) {
             errno = 0;
@@ -742,18 +721,18 @@ psutil_net_io_counters(PyObject *self, PyObject *args)
 
 #if defined(_INT64_TYPE)
         py_ifc_info = Py_BuildValue("(KKKKkkii)",
-                                    rbytes->value.ui64,
                                     wbytes->value.ui64,
-                                    rpkts->value.ui64,
+                                    rbytes->value.ui64,
                                     wpkts->value.ui64,
+                                    rpkts->value.ui64,
                                     ierrs->value.ui32,
                                     oerrs->value.ui32,
 #else
         py_ifc_info = Py_BuildValue("(kkkkkkii)",
-                                    rbytes->value.ui32,
                                     wbytes->value.ui32,
-                                    rpkts->value.ui32,
+                                    rbytes->value.ui32,
                                     wpkts->value.ui32,
+                                    rpkts->value.ui32,
                                     ierrs->value.ui32,
                                     oerrs->value.ui32,
 #endif
@@ -802,10 +781,9 @@ static int PSUTIL_CONN_NONE = 128;
  *     cmd-inet/usr.bin/netstat/netstat.c
  */
 static PyObject *
-psutil_net_connections(PyObject *self, PyObject *args)
-{
+psutil_net_connections(PyObject *self, PyObject *args) {
     long pid;
-    int sd = NULL;
+    int sd = 0;
     mib2_tcpConnEntry_t *tp = NULL;
     mib2_udpEntry_t     *ude;
 #if defined(AF_INET6)
@@ -817,6 +795,7 @@ psutil_net_connections(PyObject *self, PyObject *args)
     char lip[200], rip[200];
     int lport, rport;
     int processed_pid;
+    int databuf_init = 0;
     struct strbuf ctlbuf, databuf;
     struct T_optmgmt_req *tor = (struct T_optmgmt_req *)buf;
     struct T_optmgmt_ack *toa = (struct T_optmgmt_ack *)buf;
@@ -917,6 +896,7 @@ psutil_net_connections(PyObject *self, PyObject *args)
             PyErr_NoMemory();
             goto error;
         }
+        databuf_init = 1;
 
         flags = 0;
         getcode = getmsg(sd, (struct strbuf *)0, &databuf, &flags);
@@ -943,9 +923,8 @@ psutil_net_connections(PyObject *self, PyObject *args)
                 py_laddr = Py_BuildValue("(si)", lip, lport);
                 if (!py_laddr)
                     goto error;
-                if (rport != 0) {
+                if (rport != 0)
                     py_raddr = Py_BuildValue("(si)", rip, rport);
-                }
                 else {
                     py_raddr = Py_BuildValue("()");
                 }
@@ -957,9 +936,8 @@ psutil_net_connections(PyObject *self, PyObject *args)
                 py_tuple = Py_BuildValue("(iiiNNiI)", -1, AF_INET, SOCK_STREAM,
                                          py_laddr, py_raddr, state,
                                          processed_pid);
-                if (!py_tuple) {
+                if (!py_tuple)
                     goto error;
-                }
                 if (PyList_Append(py_retlist, py_tuple))
                     goto error;
                 Py_DECREF(py_tuple);
@@ -986,12 +964,10 @@ psutil_net_connections(PyObject *self, PyObject *args)
                 py_laddr = Py_BuildValue("(si)", lip, lport);
                 if (!py_laddr)
                     goto error;
-                if (rport != 0) {
+                if (rport != 0)
                     py_raddr = Py_BuildValue("(si)", rip, rport);
-                }
-                else {
+                else
                     py_raddr = Py_BuildValue("()");
-                }
                 if (!py_raddr)
                     goto error;
                 state = tp6->tcp6ConnEntryInfo.ce_state;
@@ -999,9 +975,8 @@ psutil_net_connections(PyObject *self, PyObject *args)
                 // add item
                 py_tuple = Py_BuildValue("(iiiNNiI)", -1, AF_INET6, SOCK_STREAM,
                                          py_laddr, py_raddr, state, processed_pid);
-                if (!py_tuple) {
+                if (!py_tuple)
                     goto error;
-                }
                 if (PyList_Append(py_retlist, py_tuple))
                     goto error;
                 Py_DECREF(py_tuple);
@@ -1034,9 +1009,8 @@ psutil_net_connections(PyObject *self, PyObject *args)
                 py_tuple = Py_BuildValue("(iiiNNiI)", -1, AF_INET, SOCK_DGRAM,
                                          py_laddr, py_raddr, PSUTIL_CONN_NONE,
                                          processed_pid);
-                if (!py_tuple) {
+                if (!py_tuple)
                     goto error;
-                }
                 if (PyList_Append(py_retlist, py_tuple))
                     goto error;
                 Py_DECREF(py_tuple);
@@ -1044,7 +1018,9 @@ psutil_net_connections(PyObject *self, PyObject *args)
         }
 #if defined(AF_INET6)
         // UDPv6
-        else if (mibhdr->level == MIB2_UDP6 || mibhdr->level == MIB2_UDP6_ENTRY) {
+        else if (mibhdr->level == MIB2_UDP6 ||
+                    mibhdr->level == MIB2_UDP6_ENTRY)
+            {
             ude6 = (mib2_udp6Entry_t *)databuf.buf;
             num_ent = mibhdr->len / sizeof(mib2_udp6Entry_t);
             for (i = 0; i < num_ent; i++, ude6++) {
@@ -1062,9 +1038,8 @@ psutil_net_connections(PyObject *self, PyObject *args)
                 py_tuple = Py_BuildValue("(iiiNNiI)", -1, AF_INET6, SOCK_DGRAM,
                                          py_laddr, py_raddr, PSUTIL_CONN_NONE,
                                          processed_pid);
-                if (!py_tuple) {
+                if (!py_tuple)
                     goto error;
-                }
                 if (PyList_Append(py_retlist, py_tuple))
                     goto error;
                 Py_DECREF(py_tuple);
@@ -1082,16 +1057,16 @@ error:
     Py_XDECREF(py_laddr);
     Py_XDECREF(py_raddr);
     Py_DECREF(py_retlist);
-    // TODO : free databuf
-    if (sd != NULL)
+    if (databuf_init == 1)
+        free(databuf.buf);
+    if (sd != 0)
         close(sd);
     return NULL;
 }
 
 
 static PyObject *
-psutil_boot_time(PyObject *self, PyObject *args)
-{
+psutil_boot_time(PyObject *self, PyObject *args) {
     float boot_time = 0.0;
     struct utmpx *ut;
 
@@ -1116,8 +1091,7 @@ psutil_boot_time(PyObject *self, PyObject *args)
  * Return the number of physical CPU cores on the system.
  */
 static PyObject *
-psutil_cpu_count_phys(PyObject *self, PyObject *args)
-{
+psutil_cpu_count_phys(PyObject *self, PyObject *args) {
     kstat_ctl_t *kc;
     kstat_t *ksp;
     int ncpus = 0;
@@ -1132,7 +1106,7 @@ psutil_cpu_count_phys(PyObject *self, PyObject *args)
     for (ksp = kc->kc_chain; ksp; ksp = ksp->ks_next) {
         if (strcmp(ksp->ks_module, "cpu_info") != 0)
             continue;
-        if (kstat_read(kc, ksp, NULL) == NULL)
+        if (kstat_read(kc, ksp, NULL) == -1)
             goto error;
         ncpus += 1;
     }
@@ -1151,12 +1125,121 @@ error:
 }
 
 
+/*
+ * Return stats about a particular network
+ * interface.  References:
+ * https://github.com/dpaleino/wicd/blob/master/wicd/backends/be-ioctl.py
+ * http://www.i-scream.org/libstatgrab/
+ */
+static PyObject*
+psutil_net_if_stats(PyObject* self, PyObject* args) {
+    kstat_ctl_t *kc = NULL;
+    kstat_t *ksp;
+    kstat_named_t *knp;
+    int ret;
+    int sock = 0;
+    int duplex;
+    int speed;
+
+    PyObject *py_retdict = PyDict_New();
+    PyObject *py_ifc_info = NULL;
+    PyObject *py_is_up = NULL;
+
+    if (py_retdict == NULL)
+        return NULL;
+    kc = kstat_open();
+    if (kc == NULL)
+        goto error;
+    sock = socket(AF_INET, SOCK_DGRAM, 0);
+    if (sock == -1)
+        goto error;
+
+    for (ksp = kc->kc_chain; ksp; ksp = ksp->ks_next) {
+        if (strcmp(ksp->ks_class, "net") == 0) {
+            struct ifreq ifr;
+
+            kstat_read(kc, ksp, NULL);
+            if (ksp->ks_type != KSTAT_TYPE_NAMED)
+                continue;
+            if (strcmp(ksp->ks_class, "net") != 0)
+                continue;
+
+            strncpy(ifr.ifr_name, ksp->ks_name, sizeof(ifr.ifr_name));
+            ret = ioctl(sock, SIOCGIFFLAGS, &ifr);
+            if (ret == -1)
+                continue;  // not a network interface
+
+            // is up?
+            if ((ifr.ifr_flags & IFF_UP) != 0) {
+                if ((knp = kstat_data_lookup(ksp, "link_up")) != NULL) {
+                    if (knp->value.ui32 != 0u)
+                        py_is_up = Py_True;
+                    else
+                        py_is_up = Py_False;
+                }
+                else {
+                    py_is_up = Py_True;
+                }
+            }
+            else {
+                py_is_up = Py_False;
+            }
+            Py_INCREF(py_is_up);
+
+            // duplex
+            duplex = 0;  // unknown
+            if ((knp = kstat_data_lookup(ksp, "link_duplex")) != NULL) {
+                if (knp->value.ui32 == 1)
+                    duplex = 1;  // half
+                else if (knp->value.ui32 == 2)
+                    duplex = 2;  // full
+            }
+
+            // speed
+            if ((knp = kstat_data_lookup(ksp, "ifspeed")) != NULL)
+                // expressed in bits per sec, we want mega bits per sec
+                speed = (int)knp->value.ui64 / 1000000;
+            else
+                speed = 0;
+
+            // mtu
+            ret = ioctl(sock, SIOCGIFMTU, &ifr);
+            if (ret == -1)
+                goto error;
+
+            py_ifc_info = Py_BuildValue("(Oiii)", py_is_up, duplex, speed,
+                                        ifr.ifr_mtu);
+            if (!py_ifc_info)
+                goto error;
+            if (PyDict_SetItemString(py_retdict, ksp->ks_name, py_ifc_info))
+                goto error;
+            Py_DECREF(py_ifc_info);
+        }
+    }
+
+    close(sock);
+    kstat_close(kc);
+    return py_retdict;
+
+error:
+    Py_XDECREF(py_is_up);
+    Py_XDECREF(py_ifc_info);
+    Py_DECREF(py_retdict);
+    if (sock != 0)
+        close(sock);
+    if (kc != NULL)
+        kstat_close(kc);
+    PyErr_SetFromErrno(PyExc_OSError);
+    return NULL;
+}
+
+
 /*
  * define the psutil C module methods and initialize the module.
  */
 static PyMethodDef
-PsutilMethods[] =
-{
+PsutilMethods[] = {
+
     // --- process-related functions
     {"proc_basic_info", psutil_proc_basic_info, METH_VARARGS,
      "Return process ppid, rss, vms, ctime, nice, nthreads, status and tty"},
@@ -1192,8 +1275,10 @@ PsutilMethods[] =
      "Return the number of physical CPUs on the system."},
     {"net_connections", psutil_net_connections, METH_VARARGS,
      "Return TCP and UDP syste-wide open connections."},
+    {"net_if_stats", psutil_net_if_stats, METH_VARARGS,
+     "Return NIC stats (isup, duplex, speed, mtu)"},
 
-{NULL, NULL, 0, NULL}
+    {NULL, NULL, 0, NULL}
 };
 
 
@@ -1277,9 +1362,8 @@ void init_psutil_sunos(void)
     PyModule_AddIntConstant(module, "TCPS_BOUND", TCPS_BOUND);
     PyModule_AddIntConstant(module, "PSUTIL_CONN_NONE", PSUTIL_CONN_NONE);
 
-    if (module == NULL) {
+    if (module == NULL)
         INITERROR;
-    }
 #if PY_MAJOR_VERSION >= 3
     return module;
 #endif
