@@ -113,6 +113,18 @@ def _convert_raw_path(s):
     return os.path.join(driveletter, s[len(rawdrive):])
 
 
+def py2_strencode(s, encoding=sys.getfilesystemencoding()):
+    if PY3 or isinstance(s, str):
+        return s
+    else:
+        try:
+            return s.encode(encoding)
+        except UnicodeEncodeError:
+            # Filesystem codec failed, return the plain unicode
+            # string (this should never happen).
+            return s
+
+
 # --- public functions
 
 
@@ -216,6 +228,7 @@ def net_connections(kind, _pid=-1):
 def net_if_stats():
     ret = cext.net_if_stats()
     for name, items in ret.items():
+        name = py2_strencode(name)
         isup, duplex, speed, mtu = items
         if hasattr(_common, 'NicDuplex'):
             duplex = _common.NicDuplex(duplex)
@@ -223,12 +236,27 @@ def net_if_stats():
     return ret
 
 
+def net_io_counters():
+    ret = cext.net_io_counters()
+    return dict([(py2_strencode(k), v) for k, v in ret.items()])
+
+
+def net_if_addrs():
+    ret = []
+    for items in cext.net_if_addrs():
+        items = list(items)
+        items[0] = py2_strencode(items[0])
+        ret.append(items)
+    return ret
+
+
 def users():
     """Return currently connected users as a list of namedtuples."""
     retlist = []
     rawlist = cext.users()
     for item in rawlist:
         user, hostname, tstamp = item
+        user = py2_strencode(user)
         nt = _common.suser(user, None, hostname, tstamp)
         retlist.append(nt)
     return retlist
@@ -236,10 +264,8 @@ def users():
 
 pids = cext.pids
 pid_exists = cext.pid_exists
-net_io_counters = cext.net_io_counters
 disk_io_counters = cext.disk_io_counters
 ppid_map = cext.ppid_map  # not meant to be public
-net_if_addrs = cext.net_if_addrs
 
 
 def wrap_exceptions(fun):
@@ -287,11 +313,9 @@ class Process(object):
             try:
                 # Note: this will fail with AD for most PIDs owned
                 # by another user but it's faster.
-                return os.path.basename(self.exe())
-            except OSError as err:
-                if err.errno in ACCESS_DENIED_SET:
-                    return cext.proc_name(self.pid)
-                raise
+                return py2_strencode(os.path.basename(self.exe()))
+            except AccessDenied:
+                return py2_strencode(cext.proc_name(self.pid))
 
     @wrap_exceptions
     def exe(self):
@@ -303,11 +327,15 @@ class Process(object):
         # see https://github.com/giampaolo/psutil/issues/528
         if self.pid in (0, 4):
             raise AccessDenied(self.pid, self._name)
-        return _convert_raw_path(cext.proc_exe(self.pid))
+        return py2_strencode(_convert_raw_path(cext.proc_exe(self.pid)))
 
     @wrap_exceptions
     def cmdline(self):
-        return cext.proc_cmdline(self.pid)
+        ret = cext.proc_cmdline(self.pid)
+        if PY3:
+            return ret
+        else:
+            return [py2_strencode(s) for s in ret]
 
     def ppid(self):
         try:
@@ -359,6 +387,10 @@ class Process(object):
     def kill(self):
         return cext.proc_kill(self.pid)
 
+    @wrap_exceptions
+    def send_signal(self, sig):
+        os.kill(self.pid, sig)
+
     @wrap_exceptions
     def wait(self, timeout=None):
         if timeout is None:
@@ -432,24 +464,26 @@ class Process(object):
         # return a normalized pathname since the native C function appends
         # "\\" at the and of the path
         path = cext.proc_cwd(self.pid)
-        return os.path.normpath(path)
+        return py2_strencode(os.path.normpath(path))
 
     @wrap_exceptions
     def open_files(self):
         if self.pid in (0, 4):
             return []
-        retlist = []
+        ret = set()
         # Filenames come in in native format like:
         # "\Device\HarddiskVolume1\Windows\systemew\file.txt"
         # Convert the first part in the corresponding drive letter
         # (e.g. "C:\") by using Windows's QueryDosDevice()
         raw_file_names = cext.proc_open_files(self.pid)
-        for file in raw_file_names:
-            file = _convert_raw_path(file)
-            if isfile_strict(file) and file not in retlist:
-                ntuple = _common.popenfile(file, -1)
-                retlist.append(ntuple)
-        return retlist
+        for _file in raw_file_names:
+            _file = _convert_raw_path(_file)
+            if isfile_strict(_file):
+                if not PY3:
+                    _file = py2_strencode(_file)
+                ntuple = _common.popenfile(_file, -1)
+                ret.add(ntuple)
+        return list(ret)
 
     @wrap_exceptions
     def connections(self, kind='inet'):
