@@ -1,14 +1,13 @@
 /*
- * $Id$
- *
  * Copyright (c) 2009, Jay Loden, Giampaolo Rodola'. All rights reserved.
  * Use of this source code is governed by a BSD-style license that can be
  * found in the LICENSE file.
  *
- * Helper functions related to fetching process information. Used by _psutil_bsd
- * module methods.
+ * Helper functions related to fetching process information.
+ * Used by _psutil_bsd module methods.
  */
 
+
 #include <Python.h>
 #include <assert.h>
 #include <errno.h>
@@ -34,10 +33,9 @@
  * On error, the function returns a BSD errno value.
  */
 int
-get_proc_list(struct kinfo_proc **procList, size_t *procCount)
-{
+psutil_get_proc_list(struct kinfo_proc **procList, size_t *procCount) {
     int err;
-    struct kinfo_proc * result;
+    struct kinfo_proc *result;
     int done;
     static const int name[] = { CTL_KERN, KERN_PROC, KERN_PROC_PROC, 0 };
     // Declaring name as const requires us to cast it when passing it to
@@ -84,7 +82,7 @@ get_proc_list(struct kinfo_proc **procList, size_t *procCount)
         // error, toss away our buffer and start again.
         if (err == 0) {
             err = sysctl((int *) name, (sizeof(name) / sizeof(*name)) - 1,
-                          result, &length, NULL, 0);
+                         result, &length, NULL, 0);
             if (err == -1)
                 err = errno;
             if (err == 0) {
@@ -114,9 +112,8 @@ get_proc_list(struct kinfo_proc **procList, size_t *procCount)
 
 
 char
-*getcmdpath(long pid, size_t *pathsize)
-{
-    int  mib[4];
+*psutil_get_cmd_path(long pid, size_t *pathsize) {
+    int mib[4];
     char *path;
     size_t size = 0;
 
@@ -129,20 +126,19 @@ char
     mib[3] = pid;
 
     // call with a null buffer first to determine if we need a buffer
-    if (sysctl(mib, 4, NULL, &size, NULL, 0) == -1) {
+    if (sysctl(mib, 4, NULL, &size, NULL, 0) == -1)
         return NULL;
-    }
 
     path = malloc(size);
     if (path == NULL) {
-        PyErr_SetString(PyExc_MemoryError, "couldn't allocate memory");
+        PyErr_NoMemory();
         return NULL;
     }
 
     *pathsize = size;
     if (sysctl(mib, 4, path, &size, NULL, 0) == -1) {
         free(path);
-        return NULL;       /* Insufficient privileges */
+        return NULL;       // Insufficient privileges
     }
 
     return path;
@@ -150,6 +146,7 @@ char
 
 
 /*
+ * XXX no longer used; it probably makese sense to remove it.
  * Borrowed from psi Python System Information project
  *
  * Get command arguments and environment variables.
@@ -162,13 +159,12 @@ char
  *      1 for insufficient privileges.
  */
 char
-*getcmdargs(long pid, size_t *argsize)
-{
-    int mib[4];
-    size_t size, argmax;
+*psutil_get_cmd_args(long pid, size_t *argsize) {
+    int mib[4], argmax;
+    size_t size = sizeof(argmax);
     char *procargs = NULL;
 
-    /* Get the maximum process arguments size. */
+    // Get the maximum process arguments size.
     mib[0] = CTL_KERN;
     mib[1] = KERN_ARGMAX;
 
@@ -176,10 +172,10 @@ char
     if (sysctl(mib, 2, &argmax, &size, NULL, 0) == -1)
         return NULL;
 
-    /* Allocate space for the arguments. */
+    // Allocate space for the arguments.
     procargs = (char *)malloc(argmax);
     if (procargs == NULL) {
-        PyErr_SetString(PyExc_MemoryError, "couldn't allocate memory");
+        PyErr_NoMemory();
         return NULL;
     }
 
@@ -194,7 +190,7 @@ char
     size = argmax;
     if (sysctl(mib, 4, procargs, &size, NULL, 0) == -1) {
         free(procargs);
-        return NULL;       /* Insufficient privileges */
+        return NULL;       // Insufficient privileges
     }
 
     // return string and set the length of arguments
@@ -203,30 +199,26 @@ char
 }
 
 
-/* returns the command line as a python list object */
-PyObject*
-get_arg_list(long pid)
-{
+// returns the command line as a python list object
+PyObject *
+psutil_get_arg_list(long pid) {
     char *argstr = NULL;
     int pos = 0;
     size_t argsize = 0;
     PyObject *retlist = Py_BuildValue("[]");
     PyObject *item = NULL;
 
-    if (pid < 0) {
+    if (pid < 0)
         return retlist;
-    }
-
-    argstr = getcmdargs(pid, &argsize);
-    if (argstr == NULL) {
+    argstr = psutil_get_cmd_args(pid, &argsize);
+    if (argstr == NULL)
         goto error;
-    }
 
     // args are returned as a flattened string with \0 separators between
     // arguments add each string to the list then step forward to the next
     // separator
     if (argsize > 0) {
-        while(pos < argsize) {
+        while (pos < argsize) {
             item = Py_BuildValue("s", &argstr[pos]);
             if (!item)
                 goto error;
@@ -253,19 +245,16 @@ error:
  * Return 1 if PID exists in the current process list, else 0.
  */
 int
-pid_exists(long pid)
-{
+psutil_pid_exists(long pid) {
     int kill_ret;
-    if (pid < 0) {
-        return 0;
-    }
 
+    if (pid < 0)
+        return 0;
     // if kill returns success of permission denied we know it's a valid PID
     kill_ret = kill(pid , 0);
-    if ((0 == kill_ret) || (EPERM == errno)) {
+    if ((0 == kill_ret) || (EPERM == errno))
         return 1;
-    }
-
     // otherwise return 0 for PID not found
     return 0;
 }
+
