@@ -1,18 +1,17 @@
 /*
- * $Id$
- *
  * Copyright (c) 2009, Jay Loden, Giampaolo Rodola'. All rights reserved.
  * Use of this source code is governed by a BSD-style license that can be
  * found in the LICENSE file.
  *
- * Helper functions related to fetching process information. Used by _psutil_osx
- * module methods.
+ * Helper functions related to fetching process information.
+ * Used by _psutil_osx module methods.
  */
 
+
 #include <Python.h>
 #include <assert.h>
 #include <errno.h>
-#include <limits.h>  /* for INT_MAX */
+#include <limits.h>  // for INT_MAX
 #include <stdbool.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -28,27 +27,22 @@
  * Return 1 if PID exists in the current process list, else 0.
  */
 int
-pid_exists(long pid)
-{
+psutil_pid_exists(long pid) {
     int kill_ret;
 
     // save some time if it's an invalid PID
-    if (pid < 0) {
+    if (pid < 0)
         return 0;
-    }
-
     // if kill returns success of permission denied we know it's a valid PID
     kill_ret = kill(pid , 0);
-    if ( (0 == kill_ret) || (EPERM == errno) ) {
+    if ( (0 == kill_ret) || (EPERM == errno))
         return 1;
-    }
 
     // otherwise return 0 for PID not found
     return 0;
 }
 
 
-
 /*
  * Returns a list of all BSD processes on the system.  This routine
  * allocates the list and puts it in *procList and a count of the
@@ -58,14 +52,13 @@ pid_exists(long pid)
  * On error, the function returns a BSD errno value.
  */
 int
-get_proc_list(kinfo_proc **procList, size_t *procCount)
-{
-    /* Declaring mib as const requires use of a cast since the
-     * sysctl prototype doesn't include the const modifier. */
+psutil_get_proc_list(kinfo_proc **procList, size_t *procCount) {
+    // Declaring mib as const requires use of a cast since the
+    // sysctl prototype doesn't include the const modifier.
     static const int mib3[3] = { CTL_KERN, KERN_PROC, KERN_PROC_ALL };
     size_t           size, size2;
     void            *ptr;
-    int              err, lim = 8;  /* some limit */
+    int              err, lim = 8;  // some limit
 
     assert( procList != NULL);
     assert(*procList == NULL);
@@ -73,7 +66,8 @@ get_proc_list(kinfo_proc **procList, size_t *procCount)
 
     *procCount = 0;
 
-    /* We start by calling sysctl with ptr == NULL and size == 0.
+    /*
+     * We start by calling sysctl with ptr == NULL and size == 0.
      * That will succeed, and set size to the appropriate length.
      * We then allocate a buffer of at least that size and call
      * sysctl with that buffer.  If that succeeds, we're done.
@@ -86,34 +80,29 @@ get_proc_list(kinfo_proc **procList, size_t *procCount)
      */
     while (lim-- > 0) {
         size = 0;
-        if (sysctl((int *)mib3, 3, NULL, &size, NULL, 0) == -1) {
+        if (sysctl((int *)mib3, 3, NULL, &size, NULL, 0) == -1)
             return errno;
-        }
-
-        size2 = size + (size >> 3);  /* add some */
+        size2 = size + (size >> 3);  // add some
         if (size2 > size) {
             ptr = malloc(size2);
-            if (ptr == NULL) {
+            if (ptr == NULL)
                 ptr = malloc(size);
-            } else {
+            else
                 size = size2;
-            }
         }
         else {
             ptr = malloc(size);
         }
-        if (ptr == NULL) {
+        if (ptr == NULL)
             return ENOMEM;
-        }
 
         if (sysctl((int *)mib3, 3, ptr, &size, NULL, 0) == -1) {
             err = errno;
             free(ptr);
-            if (err != ENOMEM) {
+            if (err != ENOMEM)
                 return err;
-            }
-
-        } else {
+        }
+        else {
             *procList = (kinfo_proc *)ptr;
             *procCount = size / sizeof(kinfo_proc);
             return 0;
@@ -123,25 +112,22 @@ get_proc_list(kinfo_proc **procList, size_t *procCount)
 }
 
 
-/* Read the maximum argument size for processes */
+// Read the maximum argument size for processes
 int
-get_argmax()
-{
+psutil_get_argmax() {
     int argmax;
     int mib[] = { CTL_KERN, KERN_ARGMAX };
     size_t size = sizeof(argmax);
 
-    if (sysctl(mib, 2, &argmax, &size, NULL, 0) == 0) {
+    if (sysctl(mib, 2, &argmax, &size, NULL, 0) == 0)
         return argmax;
-    }
     return 0;
 }
 
 
-/* return process args as a python list */
-PyObject*
-get_arg_list(long pid)
-{
+// return process args as a python list
+PyObject *
+psutil_get_arg_list(long pid) {
     int mib[3];
     int nargs;
     int len;
@@ -153,13 +139,12 @@ get_arg_list(long pid)
     PyObject *arg = NULL;
     PyObject *arglist = NULL;
 
-    //special case for PID 0 (kernel_task) where cmdline cannot be fetched
-    if (pid == 0) {
+    // special case for PID 0 (kernel_task) where cmdline cannot be fetched
+    if (pid == 0)
         return Py_BuildValue("[]");
-    }
 
-    /* read argmax and allocate memory for argument space. */
-    argmax = get_argmax();
+    // read argmax and allocate memory for argument space.
+    argmax = psutil_get_argmax();
     if (! argmax) {
         PyErr_SetFromErrno(PyExc_OSError);
         goto error;
@@ -171,23 +156,23 @@ get_arg_list(long pid)
         goto error;
     }
 
-    /* read argument space */
+    // read argument space
     mib[0] = CTL_KERN;
     mib[1] = KERN_PROCARGS2;
     mib[2] = pid;
     if (sysctl(mib, 3, procargs, &argmax, NULL, 0) < 0) {
-        if (EINVAL == errno) { // invalid == access denied OR nonexistent PID
-            if ( pid_exists(pid) ) {
+        if (EINVAL == errno) {
+            // EINVAL == access denied OR nonexistent PID
+            if (psutil_pid_exists(pid))
                 AccessDenied();
-            } else {
+            else
                 NoSuchProcess();
-            }
         }
         goto error;
     }
 
     arg_end = &procargs[argmax];
-    /* copy the number of arguments to nargs */
+    // copy the number of arguments to nargs
     memcpy(&nargs, procargs, sizeof(nargs));
 
     arg_ptr = procargs + sizeof(nargs);
@@ -201,12 +186,11 @@ get_arg_list(long pid)
 
     // skip ahead to the first argument
     for (; arg_ptr < arg_end; arg_ptr++) {
-        if (*arg_ptr != '\0') {
+        if (*arg_ptr != '\0')
             break;
-        }
     }
 
-    /* iterate through arguments */
+    // iterate through arguments
     curr_arg = arg_ptr;
     arglist = Py_BuildValue("[]");
     if (!arglist)
@@ -238,8 +222,7 @@ error:
 
 
 int
-get_kinfo_proc(pid_t pid, struct kinfo_proc *kp)
-{
+psutil_get_kinfo_proc(pid_t pid, struct kinfo_proc *kp) {
     int mib[4];
     size_t len;
     mib[0] = CTL_KERN;
@@ -257,9 +240,7 @@ get_kinfo_proc(pid_t pid, struct kinfo_proc *kp)
         return -1;
     }
 
-    /*
-     * sysctl succeeds but len is zero, happens when process has gone away
-     */
+    // sysctl succeeds but len is zero, happens when process has gone away
     if (len == 0) {
         NoSuchProcess();
         return -1;
@@ -272,11 +253,10 @@ get_kinfo_proc(pid_t pid, struct kinfo_proc *kp)
  * A thin wrapper around proc_pidinfo()
  */
 int
-psutil_proc_pidinfo(long pid, int flavor, void *pti, int size)
-{
+psutil_proc_pidinfo(long pid, int flavor, void *pti, int size) {
     int ret = proc_pidinfo((int)pid, flavor, 0, pti, size);
     if (ret == 0) {
-        if (! pid_exists(pid)) {
+        if (! psutil_pid_exists(pid)) {
             NoSuchProcess();
             return 0;
         }
