@@ -8,13 +8,16 @@
 
 from __future__ import division
 import contextlib
+import errno
 import fcntl
+import io
 import os
 import pprint
 import re
 import socket
 import struct
 import sys
+import tempfile
 import time
 import warnings
 
@@ -23,14 +26,14 @@ try:
 except ImportError:
     import mock  # requires "pip install mock"
 
-from test_psutil import POSIX, TOLERANCE, TRAVIS, LINUX
+from test_psutil import POSIX, MEMORY_TOLERANCE, TRAVIS, LINUX
 from test_psutil import (skip_on_not_implemented, sh, get_test_subprocess,
                          retry_before_failing, get_kernel_version, unittest,
-                         which)
+                         which, call_until)
 
 import psutil
 import psutil._pslinux
-from psutil._compat import PY3
+from psutil._compat import PY3, u
 
 
 SIOCGIFADDR = 0x8915
@@ -128,28 +131,28 @@ class LinuxSpecificTestCase(unittest.TestCase):
         lines = sh('free').split('\n')[1:]
         used = int(lines[0].split()[2]) * 1024
         self.assertAlmostEqual(used, psutil.virtual_memory().used,
-                               delta=TOLERANCE)
+                               delta=MEMORY_TOLERANCE)
 
     @retry_before_failing()
     def test_vmem_free(self):
         lines = sh('free').split('\n')[1:]
         free = int(lines[0].split()[3]) * 1024
         self.assertAlmostEqual(free, psutil.virtual_memory().free,
-                               delta=TOLERANCE)
+                               delta=MEMORY_TOLERANCE)
 
     @retry_before_failing()
     def test_vmem_buffers(self):
         lines = sh('free').split('\n')[1:]
         buffers = int(lines[0].split()[5]) * 1024
         self.assertAlmostEqual(buffers, psutil.virtual_memory().buffers,
-                               delta=TOLERANCE)
+                               delta=MEMORY_TOLERANCE)
 
     @retry_before_failing()
     def test_vmem_cached(self):
         lines = sh('free').split('\n')[1:]
         cached = int(lines[0].split()[6]) * 1024
         self.assertAlmostEqual(cached, psutil.virtual_memory().cached,
-                               delta=TOLERANCE)
+                               delta=MEMORY_TOLERANCE)
 
     def test_swapmem_total(self):
         lines = sh('free').split('\n')[1:]
@@ -161,14 +164,14 @@ class LinuxSpecificTestCase(unittest.TestCase):
         lines = sh('free').split('\n')[1:]
         used = int(lines[2].split()[2]) * 1024
         self.assertAlmostEqual(used, psutil.swap_memory().used,
-                               delta=TOLERANCE)
+                               delta=MEMORY_TOLERANCE)
 
     @retry_before_failing()
     def test_swapmem_free(self):
         lines = sh('free').split('\n')[1:]
         free = int(lines[2].split()[3]) * 1024
         self.assertAlmostEqual(free, psutil.swap_memory().free,
-                               delta=TOLERANCE)
+                               delta=MEMORY_TOLERANCE)
 
     @unittest.skipIf(TRAVIS, "unknown failure on travis")
     def test_cpu_times(self):
@@ -259,19 +262,29 @@ class LinuxSpecificTestCase(unittest.TestCase):
     def test_cpu_count_logical_mocked(self):
         import psutil._pslinux
         original = psutil._pslinux.cpu_count_logical()
+        # Here we want to mock os.sysconf("SC_NPROCESSORS_ONLN") in
+        # order to cause the parsing of /proc/cpuinfo and /proc/stat.
         with mock.patch(
                 'psutil._pslinux.os.sysconf', side_effect=ValueError) as m:
-            # Here we want to mock os.sysconf("SC_NPROCESSORS_ONLN") in
-            # order to test /proc/cpuinfo parsing.
-            # We might also test /proc/stat parsing but mocking open()
-            # like that is too difficult.
             self.assertEqual(psutil._pslinux.cpu_count_logical(), original)
             assert m.called
-            # Have open() return emtpy data and make sure None is returned
-            # ('cause we want to mimick os.cpu_count())
+
+            # Let's have open() return emtpy data and make sure None is
+            # returned ('cause we mimick os.cpu_count()).
             with mock.patch('psutil._pslinux.open', create=True) as m:
                 self.assertIsNone(psutil._pslinux.cpu_count_logical())
-                assert m.called
+                self.assertEqual(m.call_count, 2)
+                # /proc/stat should be the last one
+                self.assertEqual(m.call_args[0][0], '/proc/stat')
+
+            # Let's push this a bit further and make sure /proc/cpuinfo
+            # parsing works as expected.
+            with open('/proc/cpuinfo', 'rb') as f:
+                cpuinfo_data = f.read()
+            fake_file = io.BytesIO(cpuinfo_data)
+            with mock.patch('psutil._pslinux.open',
+                            return_value=fake_file, create=True) as m:
+                self.assertEqual(psutil._pslinux.cpu_count_logical(), original)
 
     def test_cpu_count_physical_mocked(self):
         # Have open() return emtpy data and make sure None is returned
@@ -280,6 +293,26 @@ class LinuxSpecificTestCase(unittest.TestCase):
             self.assertIsNone(psutil._pslinux.cpu_count_physical())
             assert m.called
 
+    def test_proc_open_files_file_gone(self):
+        # simulates a file which gets deleted during open_files()
+        # execution
+        p = psutil.Process()
+        files = p.open_files()
+        with tempfile.NamedTemporaryFile():
+            # give the kernel some time to see the new file
+            call_until(p.open_files, "len(ret) != %i" % len(files))
+            with mock.patch('psutil._pslinux.os.readlink',
+                            side_effect=OSError(errno.ENOENT, "")) as m:
+                files = p.open_files()
+                assert not files
+                assert m.called
+            # also simulate the case where os.readlink() returns EINVAL
+            # in which case psutil is supposed to 'continue'
+            with mock.patch('psutil._pslinux.os.readlink',
+                            side_effect=OSError(errno.EINVAL, "")) as m:
+                self.assertEqual(p.open_files(), [])
+                assert m.called
+
     def test_proc_terminal_mocked(self):
         with mock.patch('psutil._pslinux._psposix._get_terminal_map',
                         return_value={}) as m:
@@ -321,6 +354,78 @@ class LinuxSpecificTestCase(unittest.TestCase):
                 psutil._pslinux.Process(os.getpid()).gids)
             assert m.called
 
+    def test_proc_cmdline_mocked(self):
+        # see: https://github.com/giampaolo/psutil/issues/639
+        p = psutil.Process()
+        fake_file = io.StringIO(u('foo\x00bar\x00'))
+        with mock.patch('psutil._pslinux.open',
+                        return_value=fake_file, create=True) as m:
+            p.cmdline() == ['foo', 'bar']
+            assert m.called
+        fake_file = io.StringIO(u('foo\x00bar\x00\x00'))
+        with mock.patch('psutil._pslinux.open',
+                        return_value=fake_file, create=True) as m:
+            p.cmdline() == ['foo', 'bar', '']
+            assert m.called
+
+    def test_proc_io_counters_mocked(self):
+        with mock.patch('psutil._pslinux.open', create=True) as m:
+            self.assertRaises(
+                NotImplementedError,
+                psutil._pslinux.Process(os.getpid()).io_counters)
+            assert m.called
+
+    def test_boot_time_mocked(self):
+        with mock.patch('psutil._pslinux.open', create=True) as m:
+            self.assertRaises(
+                RuntimeError,
+                psutil._pslinux.boot_time)
+            assert m.called
+
+    def test_users_mocked(self):
+        # Make sure ':0' and ':0.0' (returned by C ext) are converted
+        # to 'localhost'.
+        with mock.patch('psutil._pslinux.cext.users',
+                        return_value=[('giampaolo', 'pts/2', ':0',
+                                      1436573184.0, True)]) as m:
+            self.assertEqual(psutil.users()[0].host, 'localhost')
+            assert m.called
+        with mock.patch('psutil._pslinux.cext.users',
+                        return_value=[('giampaolo', 'pts/2', ':0.0',
+                                      1436573184.0, True)]) as m:
+            self.assertEqual(psutil.users()[0].host, 'localhost')
+            assert m.called
+        # ...otherwise it should be returned as-is
+        with mock.patch('psutil._pslinux.cext.users',
+                        return_value=[('giampaolo', 'pts/2', 'foo',
+                                      1436573184.0, True)]) as m:
+            self.assertEqual(psutil.users()[0].host, 'foo')
+            assert m.called
+
+    def test_disk_partitions_mocked(self):
+        # Test that ZFS partitions are returned.
+        with open("/proc/filesystems", "r") as f:
+            data = f.read()
+        if 'zfs' in data:
+            for part in psutil.disk_partitions():
+                if part.fstype == 'zfs':
+                    break
+            else:
+                self.fail("couldn't find any ZFS partition")
+        else:
+            # No ZFS partitions on this system. Let's fake one.
+            fake_file = io.StringIO(u("nodev\tzfs\n"))
+            with mock.patch('psutil._pslinux.open',
+                            return_value=fake_file, create=True) as m1:
+                with mock.patch(
+                        'psutil._pslinux.cext.disk_partitions',
+                        return_value=[('/dev/sdb3', '/', 'zfs', 'rw')]) as m2:
+                    ret = psutil.disk_partitions()
+                    assert m1.called
+                    assert m2.called
+                    assert ret
+                    self.assertEqual(ret[0].fstype, 'zfs')
+
     # --- tests for specific kernel versions
 
     @unittest.skipUnless(
